CacheMe

Struct CacheMe 

pub struct CacheMe<B> { /* private fields */ }
get_me cache.

Bot’s user is hardly ever changed, so sometimes it’s reasonable to cache response from get_me method.

Implementations

Source

impl<B> CacheMe<B>

pub fn new(bot: B) -> CacheMe<B>

Available on crate feature cache_me only.

Creates new cache.

Note: it’s recommended to use RequesterExt::cache_me instead.

pub fn inner(&self) -> &B

Available on crate feature cache_me only.

Allows to access inner bot

pub fn into_inner(self) -> B

Available on crate feature cache_me only.

Unwraps inner bot

pub fn clear(&mut self) -> Option<Me>

Available on crate feature cache_me only.

Clear cache.

Returns cached response from get_me, if it was cached.

Note: internally this uses Arc::make_mut so this will not clear cache of clones of self.