pub struct EditForumTopic {
pub chat_id: Recipient,
pub message_thread_id: ThreadId,
pub name: Option<String>,
pub icon_custom_emoji_id: Option<CustomEmojiId>,
}Expand description
Use this method to edit name and icon of a topic in a forum supergroup chat. The bot must be an administrator in the chat for this to work and must have can_manage_topics administrator rights, unless it is the creator of the topic. Returns True on success.
Fields
chat_id: RecipientUnique identifier for the target chat or username of the target channel (in the format @channelusername)
message_thread_id: ThreadIdUnique identifier for the target message thread of the forum topic
name: Option<String>Topic name, 0-128 characters. If not specified or empty, the current name of the topic will be kept
icon_custom_emoji_id: Option<CustomEmojiId>Unique identifier of the custom emoji shown as the topic icon. Use getForumTopicIconStickers to get all allowed custom emoji identifiers. Pass an empty string to remove the icon. If not specified, the current icon will be kept
Implementations