pub struct ForwardMessage {
pub chat_id: Recipient,
pub from_chat_id: Recipient,
pub message_id: MessageId,
pub message_thread_id: Option<ThreadId>,
pub video_start_timestamp: Option<Seconds>,
pub disable_notification: Option<bool>,
pub protect_content: Option<bool>,
pub message_effect_id: Option<EffectId>,
}Expand description
Use this method to forward messages of any kind. On success, the sent Message is returned.
Fields
chat_id: RecipientUnique identifier for the target chat or username of the target channel (in the format @channelusername)
from_chat_id: RecipientUnique identifier for the chat where the original message was sent (or channel username in the format @channelusername)
message_id: MessageIdMessage identifier in the chat specified in from_chat_id
message_thread_id: Option<ThreadId>Unique identifier for the target message thread (topic) of the forum; for forum supergroups only
video_start_timestamp: Option<Seconds>New start timestamp for the forwarded video in the message
disable_notification: Option<bool>Sends the message silently. Users will receive a notification with no sound.
protect_content: Option<bool>Protects the contents of sent messages from forwarding and saving
message_effect_id: Option<EffectId>Unique identifier of the message effect to be added to the message; for private chats only
Implementations