pub struct RemoveChatVerification {
pub chat_id: Recipient,
}Expand description
Removes verification from a chat that is currently verified on behalf of the organization represented by the bot. Returns true on success.
Fields
chat_id: RecipientUnique identifier for the target chat or username of the target channel
Implementations