pub struct ReopenForumTopic {
pub chat_id: Recipient,
pub message_thread_id: ThreadId,
}Expand description
Use this method to reopen a closed topic in a forum supergroup chat. The bot must be an administrator in the chat for this to work and must have the can_manage_topics administrator rights, unless it is the creator of the topic. Returns True on success.
Fields
chat_id: RecipientUnique identifier for the target chat or username of the target channel (in the format @channelusername)
message_thread_id: ThreadIdUnique identifier for the target message thread of the forum topic
Implementations