pub struct SendAudio {Show 17 fields
pub chat_id: Recipient,
pub audio: InputFile,
pub business_connection_id: Option<BusinessConnectionId>,
pub message_thread_id: Option<ThreadId>,
pub caption: Option<String>,
pub parse_mode: Option<ParseMode>,
pub caption_entities: Option<Vec<MessageEntity>>,
pub duration: Option<u32>,
pub performer: Option<String>,
pub title: Option<String>,
pub thumbnail: Option<InputFile>,
pub disable_notification: Option<bool>,
pub protect_content: Option<bool>,
pub allow_paid_broadcast: Option<bool>,
pub message_effect_id: Option<EffectId>,
pub reply_parameters: Option<ReplyParameters>,
pub reply_markup: Option<ReplyMarkup>,
}Expand description
Use this method to send audio files, if you want Telegram clients to display them in the music player. Your audio must be in the .MP3 or .M4A format. On success, the sent Message is returned. Bots can currently send audio files of up to 50 MB in size, this limit may be changed in the future.
For sending voice messages, use the SendVoice method instead.
Fields
chat_id: RecipientUnique identifier for the target chat or username of the target channel (in the format @channelusername)
audio: InputFileAudio file to send. Pass a file_id as FileId to send an audio file that exists on the Telegram servers (recommended), pass an HTTP URL as a String for Telegram to get an audio file from the Internet, or upload a new one using multipart/form-data. More info on Sending Files »
business_connection_id: Option<BusinessConnectionId>Unique identifier of the business connection on behalf of which the message will be sent
message_thread_id: Option<ThreadId>Unique identifier for the target message thread (topic) of the forum; for forum supergroups only
caption: Option<String>Audio caption, 0-1024 characters after entities parsing
parse_mode: Option<ParseMode>Mode for parsing entities in the audio caption. See formatting options for more details.
caption_entities: Option<Vec<MessageEntity>>List of special entities that appear in the photo caption, which can be specified instead of parse_mode
duration: Option<u32>Duration of the audio in seconds
performer: Option<String>Performer
title: Option<String>Track name
thumbnail: Option<InputFile>Thumbnail of the file sent; can be ignored if thumbnail generation for the file is supported server-side. The thumbnail should be in JPEG format and less than 200 kB in size. A thumbnail’s width and height should not exceed 320. Ignored if the file is not uploaded using multipart/form-data. Thumbnails can’t be reused and can be only uploaded as a new file, so you can pass “attach://<file_attach_name>” if the thumbnail was uploaded using multipart/form-data under <file_attach_name>. More info on Sending Files »
disable_notification: Option<bool>Sends the message silently. Users will receive a notification with no sound.
protect_content: Option<bool>Protects the contents of sent messages from forwarding and saving
allow_paid_broadcast: Option<bool>Pass true to allow up to 1000 messages per second, ignoring broadcasting limits for a fee of 0.1 Telegram Stars per message. The relevant Stars will be withdrawn from the bot’s balance
message_effect_id: Option<EffectId>Unique identifier of the message effect to be added to the message; for private chats only
reply_parameters: Option<ReplyParameters>Description of the message to reply to
reply_markup: Option<ReplyMarkup>Additional interface options. A JSON-serialized object for an inline keyboard, custom reply keyboard, instructions to remove a reply keyboard or to force a reply from the user. Not supported for messages sent on behalf of a business account.
Implementations