pub struct SendChecklist {
pub business_connection_id: BusinessConnectionId,
pub chat_id: ChatId,
pub checklist: InputChecklist,
pub disable_notification: Option<bool>,
pub protect_content: Option<bool>,
pub message_effect_id: Option<EffectId>,
pub reply_parameters: Option<ReplyParameters>,
pub reply_markup: Option<ReplyMarkup>,
}Expand description
Use this method to send a checklist on behalf of a connected business account. On success, the sent Message is returned.
Fields
business_connection_id: BusinessConnectionIdUnique identifier of the business connection on behalf of which the message will be sent
chat_id: ChatIdUnique identifier for the target chat
checklist: InputChecklistChecklist to send
disable_notification: Option<bool>Sends the message silently. Users will receive a notification with no sound
protect_content: Option<bool>Protects the contents of sent messages from forwarding and saving
message_effect_id: Option<EffectId>Unique identifier of the message effect to be added to the message
reply_parameters: Option<ReplyParameters>Description of the message to reply to
reply_markup: Option<ReplyMarkup>An inline keyboard
Implementations
Sourceimpl SendChecklist
impl SendChecklist
pub fn new( business_connection_id: BusinessConnectionId, chat_id: impl Into<ChatId>, checklist: InputChecklist, ) -> SendChecklist ⓘ