pub struct SendMessageDraft {
pub chat_id: ChatId,
pub draft_id: u32,
pub text: String,
pub message_thread_id: Option<ThreadId>,
pub parse_mode: Option<ParseMode>,
pub entities: Option<Vec<MessageEntity>>,
}Expand description
Use this method to stream a partial message to a user while the message is being generated; supported only for bots with forum topic mode enabled. Returns true on success.
Fields
chat_id: ChatIdUnique identifier for the target private chat
draft_id: u32Unique identifier of the message draft; must be non-zero. Changes of drafts with the same identifier are animated
text: StringText of the message to be sent, 1-4096 characters after entities parsing
message_thread_id: Option<ThreadId>Unique identifier for the target message thread
parse_mode: Option<ParseMode>Mode for parsing entities in the message text. See formatting options for more details.
entities: Option<Vec<MessageEntity>>List of special entities that appear in message text, which can be specified instead of parse_mode
Implementations