pub struct SendSticker {
pub chat_id: Recipient,
pub sticker: InputFile,
pub business_connection_id: Option<BusinessConnectionId>,
pub message_thread_id: Option<ThreadId>,
pub emoji: Option<String>,
pub disable_notification: Option<bool>,
pub protect_content: Option<bool>,
pub allow_paid_broadcast: Option<bool>,
pub message_effect_id: Option<EffectId>,
pub reply_parameters: Option<ReplyParameters>,
pub reply_markup: Option<ReplyMarkup>,
}Expand description
Use this method to send static .WEBP, .TGS or .WEBM stickers. On success, the sent Message is returned.
Fields
chat_id: RecipientUnique identifier for the target chat or username of the target channel (in the format @channelusername).
sticker: InputFileSticker to send. Pass a file_id as FileId to send a photo that exists on the Telegram servers (recommended), pass an HTTP URL as a String for Telegram to get a photo from the Internet, or upload a new photo using multipart/form-data. More info on Sending Files »
business_connection_id: Option<BusinessConnectionId>Unique identifier of the business connection on behalf of which the message will be sent
message_thread_id: Option<ThreadId>Unique identifier for the target message thread (topic) of the forum; for forum supergroups only
emoji: Option<String>Emoji associated with the sticker; only for just uploaded stickers
disable_notification: Option<bool>Sends the message silently. Users will receive a notification with no sound.
protect_content: Option<bool>Protects the contents of sent messages from forwarding and saving
allow_paid_broadcast: Option<bool>Pass true to allow up to 1000 messages per second, ignoring broadcasting limits for a fee of 0.1 Telegram Stars per message. The relevant Stars will be withdrawn from the bot’s balance
message_effect_id: Option<EffectId>Unique identifier of the message effect to be added to the message; for private chats only
reply_parameters: Option<ReplyParameters>Description of the message to reply to
reply_markup: Option<ReplyMarkup>Additional interface options. A JSON-serialized object for an inline keyboard, custom reply keyboard, instructions to remove a reply keyboard or to force a reply from the user. Not supported for messages sent on behalf of a business account.
Implementations
Sourceimpl SendSticker
impl SendSticker