SetStickerMaskPosition

Struct SetStickerMaskPosition 

pub struct SetStickerMaskPosition {
    pub sticker: String,
    pub mask_position: Option<MaskPosition>,
}
Use this method to change the mask position of a mask sticker. The sticker must belong to a sticker set that was created by the bot. Returns True on success.

Fields

sticker: String

File identifier of the sticker

mask_position: Option<MaskPosition>

A JSON-serialized object with the position where the mask should be placed on faces. Omit the parameter to remove the mask position.

Implementations