Bot

Struct Bot 

pub struct Bot { /* private fields */ }
A requests sender.

This is the main type of the library, it allows to send requests to the Telegram Bot API and download files.

TBA methods

All TBA methods are located in the Requester impl for Bot. This allows for opt-in behaviours using requester adaptors.

use teloxide_core_ng::prelude::*;

let bot = Bot::new("TOKEN");
dbg!(bot.get_me().await?);

File download

In the similar way as with TBA methods, file downloading methods are located in a trait — Download<'_>. See its documentation for more.

Clone cost

Bot::clone is relatively cheap, so if you need to share Bot, it’s recommended to clone it, instead of wrapping it in Arc<_>.

Implementations

Source

impl Bot

Constructors

pub fn new<S>(token: S) -> Bot
where S: Into<String>,

Creates a new Bot with the specified token and the default http-client.

Panics

If it cannot create reqwest::Client.

pub fn with_client<S>(token: S, client: Client) -> Bot
where S: Into<String>,

Creates a new Bot with the specified token and your reqwest::Client.

Caution

Your custom client might not be configured correctly to be able to work in long time durations, see issue 223.

pub fn from_env() -> Bot

Creates a new Bot with the TELOXIDE_TOKEN & TELOXIDE_API_URL & TELOXIDE_PROXY environmental variables (the bot’s token & the bot’s API URL & the proxy) and the default reqwest::Client.

If TELOXIDE_API_URL doesn’t exist, returns to the default TBA URL.

This function passes the value of TELOXIDE_PROXY into reqwest::Proxy::all, if it exists, otherwise returns the default client.

Panics
  • If cannot get the TELOXIDE_TOKEN environmental variable.
  • If TELOXIDE_API_URL exists, but isn’t a correct URL.
  • If it cannot create reqwest::Client.
Examples found in repository?
examples/command.rs (line 8)
4async fn main() {
5    pretty_env_logger::init();
6    log::info!("Starting command bot...");
7
8    let bot = Bot::from_env();
9
10    Command::repl(bot, answer).await;
11}
More examples
Hide additional examples
examples/admin.rs (line 59)
55async fn main() {
56    pretty_env_logger::init();
57    log::info!("Starting admin bot...");
58
59    let bot = teloxide_ng::Bot::from_env();
60
61    Command::repl(bot, action).await;
62}
examples/throw_dice.rs (line 10)
6async fn main() {
7    pretty_env_logger::init();
8    log::info!("Starting throw dice bot...");
9
10    let bot = Bot::from_env();
11
12    teloxide_ng::repl(bot, |bot: Bot, msg: Message| async move {
13        bot.send_dice(msg.chat.id).await?;
14        Ok(())
15    })
16    .await;
17}
examples/purchase.rs (line 52)
48async fn main() {
49    pretty_env_logger::init();
50    log::info!("Starting purchase bot...");
51
52    let bot = Bot::from_env();
53
54    Dispatcher::builder(bot, schema())
55        .dependencies(dptree::deps![InMemStorage::<State>::new()])
56        .enable_ctrlc_handler()
57        .build()
58        .dispatch()
59        .await;
60}
examples/buttons.rs (line 28)
24async fn main() -> Result<(), Box<dyn Error>> {
25    pretty_env_logger::init();
26    log::info!("Starting buttons bot...");
27
28    let bot = Bot::from_env();
29
30    let handler = dptree::entry()
31        .branch(Update::filter_message().endpoint(message_handler))
32        .branch(Update::filter_callback_query().endpoint(callback_handler))
33        .branch(Update::filter_inline_query().endpoint(inline_query_handler));
34
35    Dispatcher::builder(bot, handler).enable_ctrlc_handler().build().dispatch().await;
36    Ok(())
37}
examples/ngrok_ping_pong.rs (line 11)
7async fn main() {
8    pretty_env_logger::init();
9    log::info!("Starting ngrok ping-pong bot...");
10
11    let bot = Bot::from_env();
12
13    let addr = ([127, 0, 0, 1], 8443).into();
14    let url = "Your HTTPS ngrok URL here. Get it by `ngrok http 8443`".parse().unwrap();
15    let listener = webhooks::axum(bot.clone(), webhooks::Options::new(addr, url))
16        .await
17        .expect("Couldn't setup webhook");
18
19    teloxide_ng::repl_with_listener(
20        bot,
21        |bot: Bot, msg: Message| async move {
22            bot.send_message(msg.chat.id, "pong").await?;
23            Ok(())
24        },
25        listener,
26    )
27    .await;
28}
pub fn from_env_with_client(client: Client) -> Bot

Creates a new Bot with the TELOXIDE_TOKEN environmental variable (the bot’s token), TELOXIDE_API_URL environmental variable (the bot’s API URL) and your reqwest::Client.

If TELOXIDE_API_URL doesn’t exist, returns to the default TBA URL.

Panics
  • If cannot get the TELOXIDE_TOKEN environmental variable.
  • If TELOXIDE_API_URL exists, but isn’t a correct URL.
Caution

Your custom client might not be configured correctly to be able to work in long time durations, see issue 223.

pub fn set_api_url(self, url: Url) -> Bot

Sets a custom API URL.

For example, you can run your own TBA server and set its URL using this method.

Examples
use teloxide_core_ng::{
    Bot,
    requests::{Request, Requester},
};

let url = reqwest::Url::parse("https://localhost/tbas").unwrap();
let bot = Bot::new("TOKEN").set_api_url(url);
// From now all methods will use "https://localhost/tbas" as an API URL.
bot.get_me().await
Multi-instance behaviour

This method only sets the URL for one bot instace, older clones are unaffected.

use teloxide_core_ng::Bot;

let bot = Bot::new("TOKEN");
let bot2 = bot.clone();
let bot = bot.set_api_url(reqwest::Url::parse("https://example.com/").unwrap());

assert_eq!(bot.api_url().as_str(), "https://example.com/");
assert_eq!(bot.clone().api_url().as_str(), "https://example.com/");
assert_ne!(bot2.api_url().as_str(), "https://example.com/");
Source

impl Bot

Getters

pub fn token(&self) -> &str

Returns currently used token.

pub fn client(&self) -> &Client

Returns currently used http-client.

pub fn api_url(&self) -> Url

Returns currently used token API URL.