pub enum ResponseParameters {
MigrateToChatId(ChatId),
RetryAfter(Seconds),
}Expand description
Contains information about why a request was unsuccessful.
Variants
MigrateToChatId(ChatId)
The group has been migrated to a supergroup with the specified identifier.
RetryAfter(Seconds)
In case of exceeding flood control, the number of seconds left to wait before the request can be repeated.