pub struct Animation {
pub file: FileMeta,
pub width: u32,
pub height: u32,
pub duration: Seconds,
pub thumbnail: Option<PhotoSize>,
pub file_name: Option<String>,
pub mime_type: Option<Mime>,
}Expand description
This object represents an animation file (GIF or H.264/MPEG-4 AVC video without sound).
Fields
file: FileMetaMetadata of the animation file.
width: u32A video width as defined by a sender.
height: u32A video height as defined by a sender.
duration: SecondsA duration of the video in seconds as defined by a sender.
thumbnail: Option<PhotoSize>An animation thumbnail as defined by a sender.
file_name: Option<String>An original animation filename as defined by a sender.
mime_type: Option<Mime>A MIME type of the file as defined by a sender.