pub struct Audio {
pub file: FileMeta,
pub duration: Seconds,
pub performer: Option<String>,
pub title: Option<String>,
pub file_name: Option<String>,
pub mime_type: Option<Mime>,
pub thumbnail: Option<PhotoSize>,
}Expand description
This object represents an audio file to be treated as music by the Telegram clients.
Fields
file: FileMetaMetadata of the audio file.
duration: SecondsA duration of the audio in seconds as defined by a sender.
performer: Option<String>A performer of the audio as defined by a sender or by audio tags.
title: Option<String>A title of the audio as defined by sender or by audio tags.
file_name: Option<String>Original filename as defined by sender
mime_type: Option<Mime>A MIME type of the file as defined by a sender.
thumbnail: Option<PhotoSize>A thumbnail of the album cover to which the music file belongs.