pub struct BackgroundTypeFill {
pub fill: BackgroundFill,
pub dark_theme_dimming: Percentage,
}Expand description
The background is automatically filled based on the selected colors.
Fields
fill: BackgroundFillThe background fill
dark_theme_dimming: PercentageDimming of the background in dark themes, as a percentage; 0-100