pub struct BackgroundTypePattern {
pub document: Document,
pub fill: BackgroundFill,
pub intensity: Percentage,
pub is_inverted: bool,
pub is_moving: bool,
}Expand description
The background is a PNG or TGV (gzipped subset of SVG with MIME type “application/x-tgwallpattern”) pattern to be combined with the background fill chosen by the user.
Fields
document: DocumentDocument with the wallpaper
fill: BackgroundFillThe background fill
intensity: PercentageIntensity of the pattern when it is shown above the filled background; 0-100
is_inverted: booltrue, if the background fill must be applied only to the pattern
itself. All other pixels are black in this case. For dark themes only
is_moving: booltrue, if the background moves slightly when the device is tilted