pub struct BusinessConnection {
pub id: BusinessConnectionId,
pub user: User,
pub user_chat_id: UserId,
pub date: DateTime<Utc>,
pub rights: Option<BusinessBotRights>,
pub is_enabled: bool,
}Expand description
Describes the connection of the bot with a business account.
Fields
id: BusinessConnectionIdUnique identifier of the business connection
user: UserBusiness account user that created the business connection
user_chat_id: UserIdThe user id of the private chat with the user who created the business connection
date: DateTime<Utc>Date the connection was established in Unix time
rights: Option<BusinessBotRights>Rights of the business bot
is_enabled: booltrue, if the connection is alive