pub struct ChatBoostSourceGiftCode {
pub user: User,
}Expand description
The boost was obtained by the creation of Telegram Premium gift codes to boost a chat. Each such code boosts the chat 4 times for the duration of the corresponding Telegram Premium subscription.
Fields
user: UserUser for which the gift code was created.