pub struct ChatJoinRequest {
pub chat: Chat,
pub from: User,
pub user_chat_id: ChatId,
pub date: DateTime<Utc>,
pub bio: Option<String>,
pub invite_link: Option<ChatInviteLink>,
}Expand description
Represents a join request sent to a chat.
Fields
chat: ChatChat to which the request was sent
from: UserUser that sent the join request
user_chat_id: ChatIdIdentifier of a private chat with the user who sent the join request. The bot can use this identifier for 5 minutes to send messages until the join request is processed, assuming no other administrator contacted the user.
date: DateTime<Utc>Date the request was sent in Unix time
bio: Option<String>Bio of the user.
invite_link: Option<ChatInviteLink>Chat invite link that was used by the user to send the join request