pub struct ChatPrivate {
pub username: Option<String>,
pub first_name: Option<String>,
pub last_name: Option<String>,
}Fields
username: Option<String>A username, for private chats, supergroups and channels if available.
first_name: Option<String>A first name of the other party in a private chat.
last_name: Option<String>A last name of the other party in a private chat.