pub struct Checklist {
pub title: String,
pub title_entities: Option<Vec<MessageEntity>>,
pub tasks: Vec<ChecklistTask>,
pub others_can_add_tasks: bool,
pub others_can_mark_tasks_as_done: bool,
}Expand description
Describes a checklist.
Fields
title: StringTitle of the checklist
title_entities: Option<Vec<MessageEntity>>Special entities that appear in the checklist title
tasks: Vec<ChecklistTask>List of tasks in the checklist
others_can_add_tasks: booltrue, if users other than the creator of the list can add tasks to the
list
others_can_mark_tasks_as_done: booltrue, if users other than the creator of the list can mark tasks as
done or not done