pub struct ChecklistTasksAdded {
pub checklist_message: Option<Box<Message>>,
pub tasks: Vec<ChecklistTask>,
}Expand description
Describes a service message about tasks added to a checklist.
Fields
checklist_message: Option<Box<Message>>Message containing the checklist to which the tasks were added. Note that the Message object in this field will not contain the reply_to_message field even if it itself is a reply
tasks: Vec<ChecklistTask>List of tasks added to the checklist