pub struct DirectMessagePriceChanged {
pub are_direct_messages_enabled: bool,
pub direct_message_star_count: Option<u32>,
}Expand description
Describes a service message about a change in the price of direct messages sent to a channel chat.
Fields
are_direct_messages_enabled: booltrue if direct messages are enabled for the channel chat; false otherwise
direct_message_star_count: Option<u32>The new number of Telegram Stars that must be paid by users for each direct message sent to the channel. Does not apply to users who have been exempted by administrators. Defaults to 0.