pub struct Document {
pub file: FileMeta,
pub thumbnail: Option<PhotoSize>,
pub file_name: Option<String>,
pub mime_type: Option<Mime>,
}Expand description
This object represents a general file (as opposed to photos, voice messages and audio files).
Fields
file: FileMetaMetadata of the document file.
thumbnail: Option<PhotoSize>A document thumbnail as defined by a sender.
file_name: Option<String>An original filename as defined by a sender.
mime_type: Option<Mime>A MIME type of the file as defined by a sender.