pub struct ExternalReplyInfo {
pub origin: MessageOrigin,
pub chat: Option<Chat>,
pub message_id: Option<MessageId>,
pub link_preview_options: Option<LinkPreviewOptions>,
pub has_media_spoiler: bool,
pub kind: ExternalReplyInfoKind,
}Expand description
This object contains information about a message that is being replied to, which may come from another chat or forum topic.
Fields
origin: MessageOriginOrigin of the message replied to by the given message.
chat: Option<Chat>Chat the original message belongs to. Available only if the chat is a supergroup or a channel.
message_id: Option<MessageId>Unique message identifier inside the original chat. Available only if the original chat is a supergroup or a channel.
link_preview_options: Option<LinkPreviewOptions>Options used for link preview generation for the original message, if it is a text message.
has_media_spoiler: booltrue, if the message media is covered by a spoiler animation.
kind: ExternalReplyInfoKindTrait Implementations
Sourceimpl Clone for ExternalReplyInfo
impl Clone for ExternalReplyInfo
Sourcefn clone(&self) -> ExternalReplyInfo
fn clone(&self) -> ExternalReplyInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExternalReplyInfo
impl Debug for ExternalReplyInfo
Sourceimpl<'de> Deserialize<'de> for ExternalReplyInfo
impl<'de> Deserialize<'de> for ExternalReplyInfo
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ExternalReplyInfo, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ExternalReplyInfo, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ExternalReplyInfo
impl PartialEq for ExternalReplyInfo
Sourceimpl Serialize for ExternalReplyInfo
impl Serialize for ExternalReplyInfo
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for ExternalReplyInfo