pub struct FileMeta {
pub id: FileId,
pub unique_id: FileUniqueId,
pub size: u32,
}Expand description
Metadata of a File.
Fields
id: FileIdIdentifier for this file.
unique_id: FileUniqueIdUnique identifier for this file, which is supposed to be the same over time and for different bots. Can’t be used to download or reuse the file.
size: u32File size in bytes.