pub struct FileUniqueId(pub String);Expand description
Unique identifier for a file, which is supposed to be the same over time and for different bots. Can’t be used to download or reuse the file.
Tuple Fields
0: StringTrait Implementations
Sourceimpl Clone for FileUniqueId
impl Clone for FileUniqueId
Sourcefn clone(&self) -> FileUniqueId
fn clone(&self) -> FileUniqueId
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FileUniqueId
impl Debug for FileUniqueId
Sourceimpl Default for FileUniqueId
impl Default for FileUniqueId
Sourcefn default() -> FileUniqueId
fn default() -> FileUniqueId
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for FileUniqueId
impl<'de> Deserialize<'de> for FileUniqueId
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<FileUniqueId, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<FileUniqueId, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for FileUniqueId
impl Display for FileUniqueId
Sourceimpl From<&'static str> for FileUniqueId
impl From<&'static str> for FileUniqueId
Sourcefn from(value: &'static str) -> FileUniqueId
fn from(value: &'static str) -> FileUniqueId
Converts to this type from the input type.
Sourceimpl From<String> for FileUniqueId
impl From<String> for FileUniqueId
Sourcefn from(value: String) -> FileUniqueId
fn from(value: String) -> FileUniqueId
Converts to this type from the input type.
Sourceimpl Hash for FileUniqueId
impl Hash for FileUniqueId
Sourceimpl PartialEq for FileUniqueId
impl PartialEq for FileUniqueId
Sourceimpl Serialize for FileUniqueId
impl Serialize for FileUniqueId
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Eq for FileUniqueId
impl StructuralPartialEq for FileUniqueId