pub struct ForceReply {
pub force_reply: True,
pub input_field_placeholder: Option<String>,
pub selective: bool,
}Expand description
Upon receiving a message with this object, Telegram clients will display a reply interface to the user (act as if the user has selected the bot‘s message and tapped ’Reply’).
This can be extremely useful if you want to create user-friendly step-by-step interfaces without having to sacrifice privacy mode.
Fields
force_reply: TrueShows reply interface to the user, as if they manually selected the bot‘s message and tapped ’Reply’.
input_field_placeholder: Option<String>The placeholder to be shown in the input field when the reply is active; 1-64 characters.
selective: boolUse this parameter if you want to force reply from specific users only.
Targets: 1) users that are @mentioned in the text of the
Message object; 2) if the bot’s message is a reply
(has reply_to_message_id), sender of the original message.
Implementations
Sourceimpl ForceReply
impl ForceReply
pub const fn new() -> ForceReply
pub fn input_field_placeholder<T>(self, val: T) -> ForceReply
Sourcepub fn selective(self) -> ForceReply
pub fn selective(self) -> ForceReply
Sets selective to true.