pub struct ForumTopicEdited {
pub name: Option<String>,
pub icon_custom_emoji_id: Option<CustomEmojiId>,
}Expand description
This object represents a service message about an edited forum topic.
Fields
name: Option<String>New name of the topic, if it was edited
icon_custom_emoji_id: Option<CustomEmojiId>New identifier of the custom emoji shown as the topic icon, if it was edited; an empty string if the icon was removed