pub struct InlineKeyboardMarkup {
pub inline_keyboard: Vec<Vec<InlineKeyboardButton>>,
}Expand description
This object represents an inline keyboard that appears right next to the message it belongs to.
Note: This will only work in Telegram versions released after 9 April, 2016. Older clients will display unsupported message.
Fields
inline_keyboard: Vec<Vec<InlineKeyboardButton>>Array of button rows, each represented by an array of
InlineKeyboardButton objects.
Implementations
Sourceimpl InlineKeyboardMarkup
Build InlineKeyboardMarkup.
impl InlineKeyboardMarkup
Build InlineKeyboardMarkup.
Examples
use teloxide_core_ng::types::{InlineKeyboardButton, InlineKeyboardMarkup};
let url = url::Url::parse("https://example.com").unwrap();
let url_button = InlineKeyboardButton::url("text".to_string(), url);
let keyboard = InlineKeyboardMarkup::default().append_row(vec![url_button]);Sourcepub fn new<I>(inline_keyboard: I) -> InlineKeyboardMarkup
pub fn new<I>(inline_keyboard: I) -> InlineKeyboardMarkup
Examples found in repository?
examples/buttons.rs (line 57)
40fn make_keyboard() -> InlineKeyboardMarkup {
41 let mut keyboard: Vec<Vec<InlineKeyboardButton>> = vec![];
42
43 let debian_versions = [
44 "Buzz", "Rex", "Bo", "Hamm", "Slink", "Potato", "Woody", "Sarge", "Etch", "Lenny",
45 "Squeeze", "Wheezy", "Jessie", "Stretch", "Buster", "Bullseye",
46 ];
47
48 for versions in debian_versions.chunks(3) {
49 let row = versions
50 .iter()
51 .map(|&version| InlineKeyboardButton::callback(version.to_owned(), version.to_owned()))
52 .collect();
53
54 keyboard.push(row);
55 }
56
57 InlineKeyboardMarkup::new(keyboard)
58}More examples
examples/purchase.rs (line 117)
110async fn receive_full_name(bot: Bot, dialogue: MyDialogue, msg: Message) -> HandlerResult {
111 match msg.text().map(ToOwned::to_owned) {
112 Some(full_name) => {
113 let products = ["Apple", "Banana", "Orange", "Potato"]
114 .map(|product| InlineKeyboardButton::callback(product, product));
115
116 bot.send_message(msg.chat.id, "Select a product:")
117 .reply_markup(InlineKeyboardMarkup::new([products]))
118 .await?;
119 dialogue.update(State::ReceiveProductChoice { full_name }).await?;
120 }
121 None => {
122 bot.send_message(msg.chat.id, "Please, send me your full name.").await?;
123 }
124 }
125
126 Ok(())
127}pub fn inline_keyboard<I>(self, val: I) -> InlineKeyboardMarkup
pub fn append_row<R>(self, buttons: R) -> InlineKeyboardMarkupwhere
R: IntoIterator<Item = InlineKeyboardButton>,
pub fn append_to_row( self, index: usize, button: InlineKeyboardButton, ) -> InlineKeyboardMarkup