pub struct InlineQueryResultAudio {
pub id: String,
pub audio_url: Url,
pub title: String,
pub caption: Option<String>,
pub parse_mode: Option<ParseMode>,
pub caption_entities: Option<Vec<MessageEntity>>,
pub performer: Option<String>,
pub audio_duration: Option<Seconds>,
pub reply_markup: Option<InlineKeyboardMarkup>,
pub input_message_content: Option<InputMessageContent>,
}Expand description
Represents a link to an MP3 audio file. By default, this audio file will be sent by the user.
Alternatively, you can use input_message_content to send a message with
the specified content instead of the audio.
Fields
id: StringUnique identifier for this result, 1-64 bytes.
audio_url: UrlA valid URL for the audio file.
title: StringTitle.
caption: Option<String>Caption, 0-1024 characters.
parse_mode: Option<ParseMode>Send Markdown or HTML, if you want Telegram apps to show bold, italic, fixed-width text or inline URLs in the media caption.
caption_entities: Option<Vec<MessageEntity>>List of special entities that appear in the caption, which can be
specified instead of parse_mode.
performer: Option<String>Performer.
audio_duration: Option<Seconds>Audio duration in seconds.
reply_markup: Option<InlineKeyboardMarkup>Inline keyboard attached to the message.
input_message_content: Option<InputMessageContent>Content of the message to be sent instead of the audio.
Implementations
Sourceimpl InlineQueryResultAudio
impl InlineQueryResultAudio
pub fn new<S1, S2>(id: S1, audio_url: Url, title: S2) -> InlineQueryResultAudio
pub fn id<S>(self, val: S) -> InlineQueryResultAudio
pub fn audio_url(self, val: Url) -> InlineQueryResultAudio
pub fn title<S>(self, val: S) -> InlineQueryResultAudio
pub fn caption<S>(self, val: S) -> InlineQueryResultAudio
pub fn parse_mode(self, val: ParseMode) -> InlineQueryResultAudio
pub fn caption_entities<C>(self, val: C) -> InlineQueryResultAudiowhere
C: IntoIterator<Item = MessageEntity>,
pub fn performer<S>(self, val: S) -> InlineQueryResultAudio
pub fn audio_duration(self, val: Seconds) -> InlineQueryResultAudio
pub fn reply_markup(self, val: InlineKeyboardMarkup) -> InlineQueryResultAudio
pub fn input_message_content( self, val: InputMessageContent, ) -> InlineQueryResultAudio