pub struct InlineQueryResultCachedAudio {
pub id: String,
pub audio_file_id: FileId,
pub caption: Option<String>,
pub parse_mode: Option<ParseMode>,
pub caption_entities: Option<Vec<MessageEntity>>,
pub reply_markup: Option<InlineKeyboardMarkup>,
pub input_message_content: Option<InputMessageContent>,
}Expand description
Represents a link to an MP3 audio file stored on the Telegram servers.
By default, this audio file will be sent by the user. Alternatively, you can
use input_message_content to send a message with the specified content
instead of the audio.
Fields
id: StringUnique identifier for this result, 1-64 bytes.
audio_file_id: FileIdA valid file identifier for the audio file.
caption: Option<String>Caption, 0-1024 characters.
parse_mode: Option<ParseMode>Send Markdown or HTML, if you want Telegram apps to show bold, italic, fixed-width text or inline URLs in the media caption.
caption_entities: Option<Vec<MessageEntity>>List of special entities that appear in the caption, which can be
specified instead of parse_mode.
reply_markup: Option<InlineKeyboardMarkup>Inline keyboard attached to the message.
input_message_content: Option<InputMessageContent>Content of the message to be sent instead of the audio.
Implementations
Sourceimpl InlineQueryResultCachedAudio
impl InlineQueryResultCachedAudio
pub fn new<S1>(id: S1, audio_file_id: FileId) -> InlineQueryResultCachedAudio
pub fn id<S>(self, val: S) -> InlineQueryResultCachedAudio
pub fn audio_file_id(self, val: FileId) -> InlineQueryResultCachedAudio
pub fn caption<S>(self, val: S) -> InlineQueryResultCachedAudio
pub fn parse_mode(self, val: ParseMode) -> InlineQueryResultCachedAudio
pub fn caption_entities<C>(self, val: C) -> InlineQueryResultCachedAudiowhere
C: IntoIterator<Item = MessageEntity>,
pub fn reply_markup( self, val: InlineKeyboardMarkup, ) -> InlineQueryResultCachedAudio
pub fn input_message_content( self, val: InputMessageContent, ) -> InlineQueryResultCachedAudio