pub struct InlineQueryResultCachedMpeg4Gif {
pub id: String,
pub mpeg4_file_id: FileId,
pub title: Option<String>,
pub caption: Option<String>,
pub parse_mode: Option<ParseMode>,
pub caption_entities: Option<Vec<MessageEntity>>,
pub show_caption_above_media: bool,
pub reply_markup: Option<InlineKeyboardMarkup>,
pub input_message_content: Option<InputMessageContent>,
}Expand description
Represents a link to a video animation (H.264/MPEG-4 AVC video without sound) stored on the Telegram servers.
By default, this animated MPEG-4 file will be sent by the user with an
optional caption. Alternatively, you can use input_message_content to send
a message with the specified content instead of the animation.
Fields
id: StringUnique identifier for this result, 1-64 bytes.
mpeg4_file_id: FileIdA valid file identifier for the MP4 file.
title: Option<String>Title for the result.
caption: Option<String>Caption of the MPEG-4 file to be sent, 0-1024 characters.
parse_mode: Option<ParseMode>Send Markdown or HTML, if you want Telegram apps to show bold, italic, fixed-width text or inline URLs in the media caption.
caption_entities: Option<Vec<MessageEntity>>List of special entities that appear in the caption, which can be
specified instead of parse_mode.
show_caption_above_media: boolPass true, if the caption must be shown above the message media.
reply_markup: Option<InlineKeyboardMarkup>Inline keyboard attached to the message.
input_message_content: Option<InputMessageContent>Content of the message to be sent instead of the video animation.
Implementations
Sourceimpl InlineQueryResultCachedMpeg4Gif
impl InlineQueryResultCachedMpeg4Gif
pub fn new<S1>(id: S1, mpeg4_file_id: FileId) -> InlineQueryResultCachedMpeg4Gif
pub fn id<S>(self, val: S) -> InlineQueryResultCachedMpeg4Gif
pub fn title<S>(self, val: S) -> InlineQueryResultCachedMpeg4Gif
pub fn caption<S>(self, val: S) -> InlineQueryResultCachedMpeg4Gif
pub fn parse_mode(self, val: ParseMode) -> InlineQueryResultCachedMpeg4Gif
pub fn caption_entities<C>(self, val: C) -> InlineQueryResultCachedMpeg4Gifwhere
C: IntoIterator<Item = MessageEntity>,
pub fn show_caption_above_media( self, val: bool, ) -> InlineQueryResultCachedMpeg4Gif
pub fn reply_markup( self, val: InlineKeyboardMarkup, ) -> InlineQueryResultCachedMpeg4Gif
pub fn input_message_content( self, val: InputMessageContent, ) -> InlineQueryResultCachedMpeg4Gif