pub struct InlineQueryResultCachedPhoto {
pub id: String,
pub photo_file_id: FileId,
pub title: Option<String>,
pub description: Option<String>,
pub caption: Option<String>,
pub parse_mode: Option<ParseMode>,
pub caption_entities: Option<Vec<MessageEntity>>,
pub show_caption_above_media: bool,
pub reply_markup: Option<InlineKeyboardMarkup>,
pub input_message_content: Option<InputMessageContent>,
}Expand description
Represents a link to a photo stored on the Telegram servers.
By default, this photo will be sent by the user with an optional caption.
Alternatively, you can use input_message_content to send a message with
the specified content instead of the photo.
Fields
id: StringUnique identifier for this result, 1-64 bytes.
photo_file_id: FileIdA valid file identifier of the photo.
title: Option<String>Title for the result.
description: Option<String>Short description of the result.
caption: Option<String>Caption of the photo to be sent, 0-1024 characters.
parse_mode: Option<ParseMode>Send Markdown or HTML, if you want Telegram apps to show bold, italic, fixed-width text or inline URLs in the media caption.
caption_entities: Option<Vec<MessageEntity>>List of special entities that appear in the caption, which can be
specified instead of parse_mode.
show_caption_above_media: boolPass true, if the caption must be shown above the message media.
reply_markup: Option<InlineKeyboardMarkup>Inline keyboard attached to the message.
input_message_content: Option<InputMessageContent>Content of the message to be sent instead of the photo.
Implementations
Sourceimpl InlineQueryResultCachedPhoto
impl InlineQueryResultCachedPhoto
pub fn new<S1>(id: S1, photo_file_id: FileId) -> InlineQueryResultCachedPhoto
pub fn id<S>(self, val: S) -> InlineQueryResultCachedPhoto
pub fn photo_file_id(self, val: FileId) -> InlineQueryResultCachedPhoto
pub fn title<S>(self, val: S) -> InlineQueryResultCachedPhoto
pub fn description<S>(self, val: S) -> InlineQueryResultCachedPhoto
pub fn caption<S>(self, val: S) -> InlineQueryResultCachedPhoto
pub fn parse_mode(self, val: ParseMode) -> InlineQueryResultCachedPhoto
pub fn caption_entities<C>(self, val: C) -> InlineQueryResultCachedPhotowhere
C: IntoIterator<Item = MessageEntity>,
pub fn show_caption_above_media(self, val: bool) -> InlineQueryResultCachedPhoto
pub fn reply_markup( self, val: InlineKeyboardMarkup, ) -> InlineQueryResultCachedPhoto
pub fn input_message_content( self, val: InputMessageContent, ) -> InlineQueryResultCachedPhoto