pub struct InlineQueryResultDocument {Show 13 fields
pub id: String,
pub title: String,
pub caption: Option<String>,
pub parse_mode: Option<ParseMode>,
pub caption_entities: Option<Vec<MessageEntity>>,
pub document_url: Url,
pub mime_type: Mime,
pub description: Option<String>,
pub reply_markup: Option<InlineKeyboardMarkup>,
pub input_message_content: Option<InputMessageContent>,
pub thumbnail_url: Option<Url>,
pub thumbnail_width: Option<u32>,
pub thumbnail_height: Option<u32>,
}Expand description
Represents a link to a file.
By default, this file will be sent by the user with an optional caption.
Alternatively, you can use input_message_content to send a message with
the specified content instead of the file. Currently, only .PDF and
.ZIP files can be sent using this method.
Fields
id: StringUnique identifier for this result, 1-64 bytes.
title: StringTitle for the result.
caption: Option<String>Caption of the document to be sent, 0-1024 characters.
parse_mode: Option<ParseMode>Send Markdown or HTML, if you want Telegram apps to show bold, italic, fixed-width text or inline URLs in the media caption.
caption_entities: Option<Vec<MessageEntity>>List of special entities that appear in the caption, which can be
specified instead of parse_mode.
document_url: UrlA valid URL for the file.
mime_type: MimeMime type of the content of the file, either application/pdf or
application/zip.
description: Option<String>Short description of the result.
reply_markup: Option<InlineKeyboardMarkup>Inline keyboard attached to the message.
input_message_content: Option<InputMessageContent>Content of the message to be sent instead of the file.
thumbnail_url: Option<Url>URL of the thumbnail (jpeg only) for the file.
thumbnail_width: Option<u32>Thumbnail width.
thumbnail_height: Option<u32>Thumbnail height.
Implementations
Sourceimpl InlineQueryResultDocument
impl InlineQueryResultDocument
pub fn id<S>(self, val: S) -> InlineQueryResultDocument
pub fn title<S>(self, val: S) -> InlineQueryResultDocument
pub fn caption<S>(self, val: S) -> InlineQueryResultDocument
pub fn parse_mode(self, val: ParseMode) -> InlineQueryResultDocument
pub fn caption_entities<C>(self, val: C) -> InlineQueryResultDocumentwhere
C: IntoIterator<Item = MessageEntity>,
pub fn document_url(self, val: Url) -> InlineQueryResultDocument
pub fn mime_type(self, val: Mime) -> InlineQueryResultDocument
pub fn description<S>(self, val: S) -> InlineQueryResultDocument
pub fn reply_markup( self, val: InlineKeyboardMarkup, ) -> InlineQueryResultDocument
pub fn input_message_content( self, val: InputMessageContent, ) -> InlineQueryResultDocument
pub fn thumbnail_url(self, val: Url) -> InlineQueryResultDocument
pub fn thumbnail_width(self, val: u32) -> InlineQueryResultDocument
pub fn thumbnail_height(self, val: u32) -> InlineQueryResultDocument