pub struct InlineQueryResultGif {Show 14 fields
pub id: String,
pub gif_url: Url,
pub gif_width: Option<u32>,
pub gif_height: Option<u32>,
pub gif_duration: Option<Seconds>,
pub thumbnail_url: Url,
pub thumbnail_mime_type: Option<String>,
pub title: Option<String>,
pub caption: Option<String>,
pub parse_mode: Option<ParseMode>,
pub caption_entities: Option<Vec<MessageEntity>>,
pub show_caption_above_media: bool,
pub reply_markup: Option<InlineKeyboardMarkup>,
pub input_message_content: Option<InputMessageContent>,
}Expand description
Represents a link to an animated GIF file.
By default, this animated GIF file will be sent by the user with optional
caption. Alternatively, you can use input_message_content to send a
message with the specified content instead of the animation.
Fields
id: StringUnique identifier for this result, 1-64 bytes.
gif_url: UrlA valid URL for the GIF file. File size must not exceed 1MB.
gif_width: Option<u32>Width of the GIF.
gif_height: Option<u32>Height of the GIF.
gif_duration: Option<Seconds>Duration of the GIF.
thumbnail_url: UrlURL of the static (JPEG or GIF) or animated (MPEG4) thumbnail for the result
thumbnail_mime_type: Option<String>MIME type of the thumbnail, must be one of “image/jpeg”, “image/gif”, or “video/mp4”. Defaults to “image/jpeg”
title: Option<String>Title for the result.
caption: Option<String>Caption of the GIF file to be sent, 0-1024 characters.
parse_mode: Option<ParseMode>Send Markdown or HTML, if you want Telegram apps to show bold, italic, fixed-width text or inline URLs in the media caption.
caption_entities: Option<Vec<MessageEntity>>List of special entities that appear in the caption, which can be
specified instead of parse_mode.
show_caption_above_media: boolPass true, if the caption must be shown above the message media.
reply_markup: Option<InlineKeyboardMarkup>Inline keyboard attached to the message.
input_message_content: Option<InputMessageContent>Content of the message to be sent instead of the GIF animation.
Implementations
Sourceimpl InlineQueryResultGif
impl InlineQueryResultGif
pub fn new<S>(id: S, gif_url: Url, thumbnail_url: Url) -> InlineQueryResultGif
pub fn id<S>(self, val: S) -> InlineQueryResultGif
pub fn gif_url(self, val: Url) -> InlineQueryResultGif
pub fn gif_width(self, val: u32) -> InlineQueryResultGif
pub fn gif_height(self, val: u32) -> InlineQueryResultGif
pub fn gif_duration(self, val: Seconds) -> InlineQueryResultGif
pub fn thumbnail_url(self, val: Url) -> InlineQueryResultGif
pub fn title<S>(self, val: S) -> InlineQueryResultGif
pub fn caption<S>(self, val: S) -> InlineQueryResultGif
pub fn parse_mode(self, val: ParseMode) -> InlineQueryResultGif
pub fn caption_entities<C>(self, val: C) -> InlineQueryResultGifwhere
C: IntoIterator<Item = MessageEntity>,
pub fn show_caption_above_media(self, val: bool) -> InlineQueryResultGif
pub fn reply_markup(self, val: InlineKeyboardMarkup) -> InlineQueryResultGif
pub fn input_message_content( self, val: InputMessageContent, ) -> InlineQueryResultGif