InlineQueryResultLocation

Struct InlineQueryResultLocation 

pub struct InlineQueryResultLocation {
Show 13 fields pub id: String, pub latitude: f64, pub longitude: f64, pub title: String, pub horizontal_accuracy: Option<f64>, pub live_period: Option<LivePeriod>, pub heading: Option<u16>, pub proximity_alert_radius: Option<u32>, pub reply_markup: Option<InlineKeyboardMarkup>, pub input_message_content: Option<InputMessageContent>, pub thumbnail_url: Option<Url>, pub thumbnail_width: Option<u32>, pub thumbnail_height: Option<u32>,
}
Represents a location on a map.

By default, the location will be sent by the user. Alternatively, you can use input_message_content to send a message with the specified content instead of the location.

The official docs.

Fields

id: String

Unique identifier for this result, 1-64 Bytes.

latitude: f64

Location latitude in degrees.

longitude: f64

Location longitude in degrees.

title: String

Location title.

horizontal_accuracy: Option<f64>

The radius of uncertainty for the location, measured in meters; 0-1500

live_period: Option<LivePeriod>

Period in seconds for which the location can be updated, should be between 60 and 86400, or 0x7FFFFFFF for live locations that can be edited indefinitely.

heading: Option<u16>

For live locations, a direction in which the user is moving, in degrees. Must be between 1 and 360 if specified.

proximity_alert_radius: Option<u32>

For live locations, a maximum distance for proximity alerts about approaching another chat member, in meters. Must be between 1 and 100000 if specified.

reply_markup: Option<InlineKeyboardMarkup>

Inline keyboard attached to the message.

input_message_content: Option<InputMessageContent>

Content of the message to be sent instead of the location.

thumbnail_url: Option<Url>

Url of the thumbnail for the result.

thumbnail_width: Option<u32>

Thumbnail width.

thumbnail_height: Option<u32>

Thumbnail height.

Implementations