pub struct InlineQueryResultPhoto {Show 13 fields
pub id: String,
pub photo_url: Url,
pub thumbnail_url: Url,
pub photo_width: Option<u32>,
pub photo_height: Option<u32>,
pub title: Option<String>,
pub description: Option<String>,
pub caption: Option<String>,
pub parse_mode: Option<ParseMode>,
pub caption_entities: Option<Vec<MessageEntity>>,
pub show_caption_above_media: bool,
pub reply_markup: Option<InlineKeyboardMarkup>,
pub input_message_content: Option<InputMessageContent>,
}Expand description
Represents a link to a photo.
By default, this photo will be sent by the user with optional caption.
Alternatively, you can use input_message_content to send a message with
the specified content instead of the photo.
Fields
id: StringUnique identifier for this result, 1-64 bytes.
photo_url: UrlA valid URL of the photo. Photo must be in jpeg format. Photo size must not exceed 5MB.
thumbnail_url: UrlURL of the thumbnail for the photo.
photo_width: Option<u32>Width of the photo.
photo_height: Option<u32>Height of the photo.
title: Option<String>Title for the result.
description: Option<String>Short description of the result.
caption: Option<String>Caption of the photo to be sent, 0-1024 characters.
parse_mode: Option<ParseMode>Send Markdown or HTML, if you want Telegram apps to show bold, italic, fixed-width text or inline URLs in the media caption.
caption_entities: Option<Vec<MessageEntity>>List of special entities that appear in the caption, which can be
specified instead of parse_mode.
show_caption_above_media: boolPass true, if the caption must be shown above the message media.
reply_markup: Option<InlineKeyboardMarkup>Inline keyboard attached to the message.
input_message_content: Option<InputMessageContent>Content of the message to be sent instead of the photo.
Implementations
Sourceimpl InlineQueryResultPhoto
impl InlineQueryResultPhoto
pub fn new<S>( id: S, photo_url: Url, thumbnail_url: Url, ) -> InlineQueryResultPhoto
pub fn id<S>(self, val: S) -> InlineQueryResultPhoto
pub fn photo_url(self, val: Url) -> InlineQueryResultPhoto
pub fn thumbnail_url<S>(self, val: Url) -> InlineQueryResultPhoto
pub fn photo_width(self, val: u32) -> InlineQueryResultPhoto
pub fn photo_height(self, val: u32) -> InlineQueryResultPhoto
pub fn title<S>(self, val: S) -> InlineQueryResultPhoto
pub fn description<S>(self, val: S) -> InlineQueryResultPhoto
pub fn caption<S>(self, val: S) -> InlineQueryResultPhoto
pub fn parse_mode(self, val: ParseMode) -> InlineQueryResultPhoto
pub fn caption_entities<C>(self, val: C) -> InlineQueryResultPhotowhere
C: IntoIterator<Item = MessageEntity>,
pub fn show_caption_above_media(self, val: bool) -> InlineQueryResultPhoto
pub fn reply_markup(self, val: InlineKeyboardMarkup) -> InlineQueryResultPhoto
pub fn input_message_content( self, val: InputMessageContent, ) -> InlineQueryResultPhoto