pub struct InlineQueryResultVideo {Show 15 fields
pub id: String,
pub video_url: Url,
pub mime_type: Mime,
pub thumbnail_url: Url,
pub title: String,
pub caption: Option<String>,
pub parse_mode: Option<ParseMode>,
pub caption_entities: Option<Vec<MessageEntity>>,
pub show_caption_above_media: bool,
pub video_width: Option<u32>,
pub video_height: Option<u32>,
pub video_duration: Option<Seconds>,
pub description: Option<String>,
pub reply_markup: Option<InlineKeyboardMarkup>,
pub input_message_content: Option<InputMessageContent>,
}Expand description
Represents a link to a page containing an embedded video player or a video file.
By default, this video file will be sent by the user with an optional
caption. Alternatively, you can use input_messaage_content to send a
message with the specified content instead of the video.
Fields
id: StringUnique identifier for this result, 1-64 bytes.
video_url: UrlA valid URL for the embedded video player or video file.
mime_type: MimeMime type of the content of video url, text/html or video/mp4.
thumbnail_url: UrlURL of the thumbnail (jpeg only) for the video.
title: StringTitle for the result.
caption: Option<String>Caption of the video to be sent, 0-1024 characters.
parse_mode: Option<ParseMode>Send Markdown or HTML, if you want Telegram apps to show bold, italic, fixed-width text or inline URLs in the media caption.
caption_entities: Option<Vec<MessageEntity>>List of special entities that appear in the caption, which can be
specified instead of parse_mode.
show_caption_above_media: boolPass true, if the caption must be shown above the message media.
video_width: Option<u32>Video width.
video_height: Option<u32>Video height.
video_duration: Option<Seconds>Video duration in seconds.
description: Option<String>Short description of the result.
reply_markup: Option<InlineKeyboardMarkup>Inline keyboard attached to the message.
input_message_content: Option<InputMessageContent>Content of the message to be sent instead of the video. This field is
required if InlineQueryResultVideo is used to send an HTML-page
as a result (e.g., a YouTube video).
Implementations
Sourceimpl InlineQueryResultVideo
impl InlineQueryResultVideo
pub fn new<S1, S2>( id: S1, video_url: Url, mime_type: Mime, thumbnail_url: Url, title: S2, ) -> InlineQueryResultVideo
pub fn id<S>(self, val: S) -> InlineQueryResultVideo
pub fn video_url(self, val: Url) -> InlineQueryResultVideo
pub fn mime_type(self, val: Mime) -> InlineQueryResultVideo
pub fn thumbnail_url(self, val: Url) -> InlineQueryResultVideo
pub fn title<S>(self, val: S) -> InlineQueryResultVideo
pub fn caption<S>(self, val: S) -> InlineQueryResultVideo
pub fn parse_mode(self, val: ParseMode) -> InlineQueryResultVideo
pub fn caption_entities<C>(self, val: C) -> InlineQueryResultVideowhere
C: IntoIterator<Item = MessageEntity>,
pub fn show_caption_above_media(self, val: bool) -> InlineQueryResultVideo
pub fn video_width(self, val: u32) -> InlineQueryResultVideo
pub fn video_height(self, val: u32) -> InlineQueryResultVideo
pub fn video_duration(self, val: Seconds) -> InlineQueryResultVideo
pub fn description<S>(self, val: S) -> InlineQueryResultVideo
pub fn reply_markup(self, val: InlineKeyboardMarkup) -> InlineQueryResultVideo
pub fn input_message_content( self, val: InputMessageContent, ) -> InlineQueryResultVideo