pub struct InlineQueryResultVoice {
pub id: String,
pub voice_url: Url,
pub title: String,
pub caption: Option<String>,
pub parse_mode: Option<ParseMode>,
pub caption_entities: Option<Vec<MessageEntity>>,
pub voice_duration: Option<Seconds>,
pub reply_markup: Option<InlineKeyboardMarkup>,
pub input_message_content: Option<InputMessageContent>,
}Expand description
Represents a link to a voice recording in an .ogg container encoded with OPUS.
By default, this voice recording will be sent by the user. Alternatively,
you can use input_message_content to send a message with the specified
content instead of the the voice message.
Fields
id: StringUnique identifier for this result, 1-64 bytes.
voice_url: UrlA valid URL for the voice recording.
title: StringRecording title.
caption: Option<String>Caption, 0-1024 characters.
parse_mode: Option<ParseMode>Send Markdown or HTML, if you want Telegram apps to show bold, italic, fixed-width text or inline URLs in the media caption.
caption_entities: Option<Vec<MessageEntity>>List of special entities that appear in the caption, which can be
specified instead of parse_mode.
voice_duration: Option<Seconds>Recording duration in seconds.
reply_markup: Option<InlineKeyboardMarkup>Inline keyboard attached to the message.
input_message_content: Option<InputMessageContent>Content of the message to be sent instead of the voice recording.
Implementations
Sourceimpl InlineQueryResultVoice
impl InlineQueryResultVoice
pub fn new<S1, S2>(id: S1, voice_url: Url, title: S2) -> InlineQueryResultVoice
pub fn id<S>(self, val: S) -> InlineQueryResultVoice
pub fn voice_url(self, val: Url) -> InlineQueryResultVoice
pub fn title<S>(self, val: S) -> InlineQueryResultVoice
pub fn caption<S>(self, val: S) -> InlineQueryResultVoice
pub fn parse_mode(self, val: ParseMode) -> InlineQueryResultVoice
pub fn caption_entities<C>(self, val: C) -> InlineQueryResultVoicewhere
C: IntoIterator<Item = MessageEntity>,
pub fn voice_duration(self, value: Seconds) -> InlineQueryResultVoice
pub fn reply_markup(self, val: InlineKeyboardMarkup) -> InlineQueryResultVoice
pub fn input_message_content( self, val: InputMessageContent, ) -> InlineQueryResultVoice