pub struct InlineQueryResultsButton {
pub text: String,
pub kind: InlineQueryResultsButtonKind,
}Expand description
This object represents a button to be shown above inline query results. You must use exactly one of the optional fields.
Fields
text: StringLabel text on the button
kind: InlineQueryResultsButtonKindTrait Implementations
Sourceimpl Clone for InlineQueryResultsButton
impl Clone for InlineQueryResultsButton
Sourcefn clone(&self) -> InlineQueryResultsButton
fn clone(&self) -> InlineQueryResultsButton
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InlineQueryResultsButton
impl Debug for InlineQueryResultsButton
Sourceimpl<'de> Deserialize<'de> for InlineQueryResultsButton
impl<'de> Deserialize<'de> for InlineQueryResultsButton
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<InlineQueryResultsButton, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<InlineQueryResultsButton, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for InlineQueryResultsButton
impl Hash for InlineQueryResultsButton
Sourceimpl PartialEq for InlineQueryResultsButton
impl PartialEq for InlineQueryResultsButton
Sourceimpl Serialize for InlineQueryResultsButton
impl Serialize for InlineQueryResultsButton
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Eq for InlineQueryResultsButton
impl StructuralPartialEq for InlineQueryResultsButton