pub struct InputChecklist {
pub title: String,
pub parse_mode: Option<ParseMode>,
pub title_entities: Option<Vec<MessageEntity>>,
pub tasks: Vec<InputChecklistTask>,
pub others_can_add_tasks: bool,
pub others_can_mark_tasks_as_done: bool,
}Expand description
Describes a checklist to create.
Fields
title: StringTitle of the checklist; 1-255 characters after entities parsing
parse_mode: Option<ParseMode>Mode for parsing entities in the title. See formatting options for more details.
title_entities: Option<Vec<MessageEntity>>List of special entities that appear in the title, which can be specified instead of parse_mode. Currently, only bold, italic, underline, strikethrough, spoiler, and custom_emoji entities are allowed
tasks: Vec<InputChecklistTask>List of 1-30 tasks in the checklist
others_can_add_tasks: boolPass true if other users can add tasks to the checklist
others_can_mark_tasks_as_done: boolPass true if other users can mark tasks as done or not done in the
checklist