pub struct InputChecklistTask {
pub id: ChecklistTaskId,
pub text: String,
pub parse_mode: Option<ParseMode>,
pub text_entities: Option<Vec<MessageEntity>>,
}Expand description
Describes a task to add to a checklist.
Fields
id: ChecklistTaskIdUnique identifier of the task; must be positive and unique among all task identifiers currently present in the checklist
text: StringText of the task; 1-100 characters after entities parsing
parse_mode: Option<ParseMode>Mode for parsing entities in the text. See formatting options for more details.
text_entities: Option<Vec<MessageEntity>>List of special entities that appear in the text, which can be specified instead of parse_mode. Currently, only bold, italic, underline, strikethrough, spoiler, and custom_emoji entities are allowed