pub struct InputMediaAnimation {
pub media: InputFile,
pub thumbnail: Option<InputFile>,
pub caption: Option<String>,
pub parse_mode: Option<ParseMode>,
pub caption_entities: Option<Vec<MessageEntity>>,
pub show_caption_above_media: bool,
pub width: Option<u16>,
pub height: Option<u16>,
pub duration: Option<u16>,
pub has_spoiler: bool,
}Expand description
Represents an animation file (GIF or H.264/MPEG-4 AVC video without sound) to be sent.
Fields
media: InputFileFile to send.
thumbnail: Option<InputFile>Thumbnail of the file sent; can be ignored if thumbnail generation for the file is supported server-side. The thumbnail should be in JPEG format and less than 200 kB in size. A thumbnail‘s width and height should not exceed 320. Ignored if the file is not uploaded using multipart/form-data.
caption: Option<String>Caption of the animation to be sent, 0-1024 characters.
parse_mode: Option<ParseMode>Send Markdown or HTML, if you want Telegram apps to show bold, italic, fixed-width text or inline URLs in the media caption.
caption_entities: Option<Vec<MessageEntity>>List of special entities that appear in the caption, which can be
specified instead of parse_mode.
show_caption_above_media: boolPass true, if the caption must be shown above the message media.
width: Option<u16>Animation width.
height: Option<u16>Animation height.
duration: Option<u16>Animation duration.
has_spoiler: boolPass true if the animation needs to be covered with a spoiler
animation.
Implementations
Sourceimpl InputMediaAnimation
impl InputMediaAnimation
pub const fn new(media: InputFile) -> InputMediaAnimation
pub fn media(self, val: InputFile) -> InputMediaAnimation
pub fn thumbnail(self, val: InputFile) -> InputMediaAnimation
pub fn caption<S>(self, val: S) -> InputMediaAnimation
pub const fn parse_mode(self, val: ParseMode) -> InputMediaAnimation
pub fn caption_entities<C>(self, val: C) -> InputMediaAnimationwhere
C: IntoIterator<Item = MessageEntity>,
pub fn show_caption_above_media(self, val: bool) -> InputMediaAnimation
pub const fn width(self, val: u16) -> InputMediaAnimation
pub const fn height(self, val: u16) -> InputMediaAnimation
pub const fn duration(self, val: u16) -> InputMediaAnimation
Sourcepub fn spoiler(self) -> InputMediaAnimation
pub fn spoiler(self) -> InputMediaAnimation
Sets has_spoiler to true.