pub struct InputMediaAudio {
pub media: InputFile,
pub thumbnail: Option<InputFile>,
pub caption: Option<String>,
pub parse_mode: Option<ParseMode>,
pub caption_entities: Option<Vec<MessageEntity>>,
pub duration: Option<u16>,
pub performer: Option<String>,
pub title: Option<String>,
}Expand description
Represents an audio file to be treated as music to be sent.
Fields
media: InputFileFile to send.
thumbnail: Option<InputFile>Thumbnail of the file sent; can be ignored if thumbnail generation for the file is supported server-side. The thumbnail should be in JPEG format and less than 200 kB in size. A thumbnail‘s width and height should not exceed 320. Ignored if the file is not uploaded using multipart/form-data.
caption: Option<String>Caption of the audio to be sent, 0-1024 characters.
parse_mode: Option<ParseMode>Send Markdown or HTML, if you want Telegram apps to show bold, italic, fixed-width text or inline URLs in the media caption.
caption_entities: Option<Vec<MessageEntity>>List of special entities that appear in the caption, which can be
specified instead of parse_mode.
duration: Option<u16>Duration of the audio in seconds.
performer: Option<String>Performer of the audio.
title: Option<String>Title of the audio.
Implementations
Sourceimpl InputMediaAudio
impl InputMediaAudio
pub const fn new(media: InputFile) -> InputMediaAudio
pub fn media(self, val: InputFile) -> InputMediaAudio
pub fn thumbnail(self, val: InputFile) -> InputMediaAudio
pub fn caption<S>(self, val: S) -> InputMediaAudio
pub const fn parse_mode(self, val: ParseMode) -> InputMediaAudio
pub fn caption_entities<C>(self, val: C) -> InputMediaAudiowhere
C: IntoIterator<Item = MessageEntity>,
pub const fn duration(self, val: u16) -> InputMediaAudio
pub fn performer<S>(self, val: S) -> InputMediaAudio
pub fn title<S>(self, val: S) -> InputMediaAudio