InputMediaVideo

Struct InputMediaVideo 

pub struct InputMediaVideo {
Show 13 fields pub media: InputFile, pub thumbnail: Option<InputFile>, pub cover: Option<InputFile>, pub start_timestamp: Option<Seconds>, pub caption: Option<String>, pub parse_mode: Option<ParseMode>, pub caption_entities: Option<Vec<MessageEntity>>, pub show_caption_above_media: bool, pub width: Option<u16>, pub height: Option<u16>, pub duration: Option<u16>, pub supports_streaming: Option<bool>, pub has_spoiler: bool,
}
Represents a video to be sent.

The official docs.

Fields

media: InputFilethumbnail: Option<InputFile>

Thumbnail of the file sent; can be ignored if thumbnail generation for the file is supported server-side. The thumbnail should be in JPEG format and less than 200 kB in size. A thumbnail‘s width and height should not exceed 320. Ignored if the file is not uploaded using multipart/form-data.

cover: Option<InputFile>

Cover for the video in the message. Pass a file_id to send a file that exists on the Telegram servers (recommended), pass an HTTP URL for Telegram to get a file from the Internet, or pass “attach://<file_attach_name>” to upload a new one using multipart/form-data under <file_attach_name> name

start_timestamp: Option<Seconds>

Start timestamp for the video in the message

caption: Option<String>

Caption of the video to be sent, 0-1024 characters.

parse_mode: Option<ParseMode>

Send Markdown or HTML, if you want Telegram apps to show bold, italic, fixed-width text or inline URLs in the media caption.

caption_entities: Option<Vec<MessageEntity>>

List of special entities that appear in the caption, which can be specified instead of parse_mode.

show_caption_above_media: bool

Pass true, if the caption must be shown above the message media.

width: Option<u16>

Video width.

height: Option<u16>

Video height.

duration: Option<u16>

Video duration.

supports_streaming: Option<bool>

Pass true, if the uploaded video is suitable for streaming.

has_spoiler: bool

Pass true if the video needs to be covered with a spoiler animation.

Implementations

Source

impl InputMediaVideo

pub const fn new(media: InputFile) -> InputMediaVideo

pub fn media(self, val: InputFile) -> InputMediaVideo

pub fn thumbnail(self, val: InputFile) -> InputMediaVideo

pub fn caption<S>(self, val: S) -> InputMediaVideo
where S: Into<String>,

pub fn cover(self, val: InputFile) -> InputMediaVideo

pub fn start_timestamp(self, val: Seconds) -> InputMediaVideo

pub const fn parse_mode(self, val: ParseMode) -> InputMediaVideo

pub fn caption_entities<C>(self, val: C) -> InputMediaVideo
where C: IntoIterator<Item = MessageEntity>,

pub fn show_caption_above_media(self, val: bool) -> InputMediaVideo

pub const fn width(self, val: u16) -> InputMediaVideo

pub const fn height(self, val: u16) -> InputMediaVideo

pub const fn duration(self, val: u16) -> InputMediaVideo

pub const fn supports_streaming(self, val: bool) -> InputMediaVideo

pub fn spoiler(self) -> InputMediaVideo

Sets has_spoiler to true.