pub struct InputMessageContentText {
pub message_text: String,
pub parse_mode: Option<ParseMode>,
pub entities: Option<Vec<MessageEntity>>,
pub link_preview_options: Option<LinkPreviewOptions>,
}Expand description
Represents the content of a text message to be sent as the result of an inline query.
Fields
message_text: StringText of the message to be sent, 1-4096 characters.
parse_mode: Option<ParseMode>Send Markdown or HTML, if you want Telegram apps to show bold, italic, fixed-width text or inline URLs in the media caption.
entities: Option<Vec<MessageEntity>>List of special entities that appear in message text, which can be
specified instead of parse_mode.
link_preview_options: Option<LinkPreviewOptions>Link preview generation options for the message
Implementations
Sourceimpl InputMessageContentText
impl InputMessageContentText
Sourcepub fn new<S>(message_text: S) -> InputMessageContentText
pub fn new<S>(message_text: S) -> InputMessageContentText
Examples found in repository?
examples/buttons.rs (line 96)
89async fn inline_query_handler(
90 bot: Bot,
91 q: InlineQuery,
92) -> Result<(), Box<dyn Error + Send + Sync>> {
93 let choose_debian_version = InlineQueryResultArticle::new(
94 "0",
95 "Chose debian version",
96 InputMessageContent::Text(InputMessageContentText::new("Debian versions:")),
97 )
98 .reply_markup(make_keyboard());
99
100 bot.answer_inline_query(q.id, vec![choose_debian_version.into()]).await?;
101
102 Ok(())
103}More examples
examples/inline.rs (lines 26-29)
9async fn main() {
10 pretty_env_logger::init();
11 log::info!("Starting inline bot...");
12
13 let bot = Bot::from_env();
14
15 let handler = Update::filter_inline_query().branch(dptree::endpoint(
16 |bot: Bot, q: InlineQuery| async move {
17 // First, create your actual response
18 let google_search = InlineQueryResultArticle::new(
19 // Each item needs a unique ID, as well as the response container for the
20 // items. These can be whatever, as long as they don't
21 // conflict.
22 "01".to_string(),
23 // What the user will actually see
24 "Google Search",
25 // What message will be sent when clicked/tapped
26 InputMessageContent::Text(InputMessageContentText::new(format!(
27 "https://www.google.com/search?q={}",
28 q.query,
29 ))),
30 );
31 // While constructing them from the struct itself is possible, it is preferred
32 // to use the builder pattern if you wish to add more
33 // information to your result. Please refer to the documentation
34 // for more detailed information about each field. https://docs.rs/teloxide/latest/teloxide/types/struct.InlineQueryResultArticle.html
35 let ddg_search = InlineQueryResultArticle::new(
36 "02".to_string(),
37 "DuckDuckGo Search".to_string(),
38 InputMessageContent::Text(InputMessageContentText::new(format!(
39 "https://duckduckgo.com/?q={}",
40 q.query
41 ))),
42 )
43 .description("DuckDuckGo Search")
44 .thumbnail_url("https://duckduckgo.com/assets/logo_header.v108.png".parse().unwrap())
45 .url("https://duckduckgo.com/about".parse().unwrap()); // Note: This is the url that will open if they click the thumbnail
46
47 let results = vec![
48 InlineQueryResult::Article(google_search),
49 InlineQueryResult::Article(ddg_search),
50 ];
51
52 // Send it off! One thing to note -- the ID we use here must be of the query
53 // we're responding to.
54 let response = bot.answer_inline_query(q.id.clone(), results).send().await;
55 if let Err(err) = response {
56 log::error!("Error in handler: {err:?}");
57 }
58 respond(())
59 },
60 ));
61
62 Dispatcher::builder(bot, handler).enable_ctrlc_handler().build().dispatch().await;
63}pub fn message_text<S>(self, val: S) -> InputMessageContentText
pub fn parse_mode(self, val: ParseMode) -> InputMessageContentText
pub fn entities<C>(self, val: C) -> InputMessageContentTextwhere
C: IntoIterator<Item = MessageEntity>,
pub fn link_preview_options( self, val: LinkPreviewOptions, ) -> InputMessageContentText