pub struct InputMessageContentVenue {
pub latitude: f64,
pub longitude: f64,
pub title: String,
pub address: String,
pub foursquare_id: Option<String>,
pub foursquare_type: Option<String>,
pub google_place_id: Option<String>,
pub google_place_type: Option<String>,
}Expand description
Represents the content of a venue message to be sent as the result of an inline query.
Fields
latitude: f64Latitude of the venue in degrees.
longitude: f64Longitude of the venue in degrees.
title: StringName of the venue.
address: StringAddress of the venue.
foursquare_id: Option<String>Foursquare identifier of the venue, if known.
foursquare_type: Option<String>Foursquare type of the venue, if known. (For example,
arts_entertainment/default, arts_entertainment/aquarium
or food/icecream.)
google_place_id: Option<String>Google Places identifier of the venue.
google_place_type: Option<String>Google Places type of the venue. (See supported types.)
Implementations
Sourceimpl InputMessageContentVenue
impl InputMessageContentVenue
pub fn new<S1, S2>( latitude: f64, longitude: f64, title: S1, address: S2, ) -> InputMessageContentVenue
pub fn latitude(self, val: f64) -> InputMessageContentVenue
pub fn longitude(self, val: f64) -> InputMessageContentVenue
pub fn title<S>(self, val: S) -> InputMessageContentVenue
pub fn address<S>(self, val: S) -> InputMessageContentVenue
pub fn foursquare_id<S>(self, val: S) -> InputMessageContentVenue
pub fn foursquare_type<S>(self, val: S) -> InputMessageContentVenue