pub struct InputPaidMediaPhoto {
pub media: InputFile,
}Expand description
The paid media to send is a photo.
Fields
media: InputFileFile to send. Pass a file_id to send a file that exists on the Telegram servers (recommended), pass an HTTP URL for Telegram to get a file from the Internet, or pass “attach://<file_attach_name>” to upload a new one using multipart/form-data under <file_attach_name> name. More information on Sending Files »
Implementations
Sourceimpl InputPaidMediaPhoto
impl InputPaidMediaPhoto
pub const fn new(media: InputFile) -> InputPaidMediaPhoto
pub fn media(self, val: InputFile) -> InputPaidMediaPhoto