pub struct InputPaidMediaVideo {
pub media: InputFile,
pub thumbnail: Option<InputFile>,
pub cover: Option<InputFile>,
pub start_timestamp: Option<Seconds>,
pub width: Option<u16>,
pub height: Option<u16>,
pub duration: Option<Seconds>,
pub supports_streaming: Option<bool>,
}Expand description
The paid media to send is a video.
Fields
media: InputFileFile to send. Pass a file_id to send a file that exists on the Telegram servers (recommended), pass an HTTP URL for Telegram to get a file from the Internet, or pass “attach://<file_attach_name>” to upload a new one using multipart/form-data under <file_attach_name> name. More information on Sending Files »
thumbnail: Option<InputFile>Thumbnail of the file sent; can be ignored if thumbnail generation for the file is supported server-side. The thumbnail should be in JPEG format and less than 200 kB in size. A thumbnail‘s width and height should not exceed 320. Ignored if the file is not uploaded using multipart/form-data. Thumbnails can’t be reused and can be only uploaded as a new file, so you can pass “attach://<file_attach_name>” if the thumbnail was uploaded using multipart/form-data under <file_attach_name>. More information on Sending Files »
cover: Option<InputFile>Cover for the video in the message. Pass a file_id to send a file that exists on the Telegram servers (recommended), pass an HTTP URL for Telegram to get a file from the Internet, or pass “attach://<file_attach_name>” to upload a new one using multipart/form-data under <file_attach_name> name
start_timestamp: Option<Seconds>Start timestamp for the video in the message
width: Option<u16>Video width.
height: Option<u16>Video height.
duration: Option<Seconds>Video duration in seconds.
supports_streaming: Option<bool>Pass true, if the uploaded video is suitable for streaming.
Implementations
Sourceimpl InputPaidMediaVideo
impl InputPaidMediaVideo
pub const fn new(media: InputFile) -> InputPaidMediaVideo
pub fn media(self, val: InputFile) -> InputPaidMediaVideo
pub fn thumbnail(self, val: InputFile) -> InputPaidMediaVideo
pub fn cover(self, val: InputFile) -> InputPaidMediaVideo
pub fn start_timestamp(self, val: Seconds) -> InputPaidMediaVideo
pub const fn width(self, val: u16) -> InputPaidMediaVideo
pub const fn height(self, val: u16) -> InputPaidMediaVideo
pub const fn duration(self, val: Seconds) -> InputPaidMediaVideo
pub const fn supports_streaming(self, val: bool) -> InputPaidMediaVideo