pub struct InputProfilePhotoAnimated {
pub animation: InputFile,
pub main_frame_timestamp: Option<f64>,
}Expand description
An animated profile photo in the MPEG4 format.
Fields
animation: InputFileThe animated profile photo. Profile photos can’t be reused and can only be uploaded as a new file, so you can pass “attach://<file_attach_name>” if the photo was uploaded using multipart/form-data under <file_attach_name>. More information on Sending Files »
main_frame_timestamp: Option<f64>Timestamp in seconds of the frame that will be used as the static profile photo. Defaults to 0.0