pub struct InputProfilePhotoStatic {
pub photo: InputFile,
}Expand description
A static profile photo in the .JPG format.
Fields
photo: InputFileThe static profile photo. Profile photos can’t be reused and can only be uploaded as a new file, so you can pass “attach://<file_attach_name>” if the photo was uploaded using multipart/form-data under <file_attach_name>. More information on Sending Files »