pub struct InputSticker {
pub sticker: InputFile,
pub format: StickerFormat,
pub emoji_list: Vec<String>,
pub mask_position: Option<MaskPosition>,
pub keywords: Vec<String>,
}Expand description
This object describes a sticker to be added to a sticker set.
Fields
sticker: InputFileThe added sticker. Pass a file_id as a FileId to send a file that already exists on the Telegram servers, pass an HTTP URL as a String for Telegram to get a file from the Internet, upload a new one using multipart/form-data, or pass “attach://<file_attach_name>” to upload a new one using multipart/form-data under <file_attach_name> name. Animated and video stickers can’t be uploaded via HTTP URL.
More information on Sending Files https://core.telegram.org/bots/api#sending-files
format: StickerFormatFormat of the added sticker, must be one of “static” for a .WEBP or .PNG image, “animated” for a .TGS animation, “video” for a WEBM video
emoji_list: Vec<String>List of 1-20 emoji associated with the sticker
mask_position: Option<MaskPosition>Position where the mask should be placed on faces. For “mask” stickers only.
keywords: Vec<String>List of 0-20 search keywords for the sticker with total length of up to 64 characters. For “regular” and “custom_emoji” stickers only.