InputStoryContentVideo

Struct InputStoryContentVideo 

pub struct InputStoryContentVideo {
    pub video: InputFile,
    pub duration: Option<f64>,
    pub cover_frame_timestamp: Option<f64>,
    pub is_animation: Option<bool>,
}
Describes a unique gift received and owned by a user or a chat.

Fields

video: InputFile

The video to post as a story. The video must be of the size 720x1280, streamable, encoded with H.265 codec, with key frames added each second in the MPEG4 format, and must not exceed 30 MB. The video can’t be reused and can only be uploaded as a new file, so you can pass “attach://<file_attach_name>” if the video was uploaded using multipart/form-data under <file_attach_name>. More information on Sending Files »

duration: Option<f64>

Precise duration of the video in seconds; 0-60

cover_frame_timestamp: Option<f64>

Timestamp in seconds of the frame that will be used as the static cover for the story. Defaults to 0.0

is_animation: Option<bool>

Pass true if the video has no sound