pub struct KeyboardButtonRequestChat {
pub request_id: RequestId,
pub chat_is_channel: bool,
pub chat_is_forum: Option<bool>,
pub chat_has_username: Option<bool>,
pub chat_is_created: Option<bool>,
pub user_administrator_rights: Option<ChatAdministratorRights>,
pub bot_administrator_rights: Option<ChatAdministratorRights>,
pub bot_is_member: bool,
pub request_title: bool,
pub request_username: bool,
pub request_photo: bool,
}Expand description
This object defines the criteria used to request a suitable chat.
Information about the selected chat will be shared with the bot when the corresponding button is pressed. The bot will be granted requested rights in the chat if appropriate. More about requesting chats »
Fields
request_id: RequestIdidentifier of the request, which will be received back in the
ChatShared object. Must be unique within the message.
chat_is_channel: boolPass true to request a channel chat, pass false to request a group
or a supergroup chat.
chat_is_forum: Option<bool>Pass true to request a forum supergroup, pass false to request a
non-forum chat. If not specified, no additional restrictions are
applied.
chat_has_username: Option<bool>Pass true to request a supergroup or a channel with a username, pass
false to request a chat without a username. If not specified, no
additional restrictions are applied.
chat_is_created: Option<bool>Pass true to request a chat owned by the user. Otherwise, no
additional restrictions are applied.
user_administrator_rights: Option<ChatAdministratorRights>Listing the required administrator rights of the user in the chat. The rights must be a superset of bot_administrator_rights. If not specified, no additional restrictions are applied.
bot_administrator_rights: Option<ChatAdministratorRights>Listing the required administrator rights of the bot in the chat. The rights must be a subset of user_administrator_rights. If not specified, no additional restrictions are applied.
bot_is_member: boolPass true to request a chat with the bot as a member. Otherwise, no
additional restrictions are applied.
request_title: boolPass true to request the chat’s title.
request_username: boolPass true to request the chat’s username.
request_photo: boolPass true to request the chat’s photo.
Implementations
Sourceimpl KeyboardButtonRequestChat
impl KeyboardButtonRequestChat
Sourcepub fn new(
request_id: RequestId,
chat_is_channel: bool,
) -> KeyboardButtonRequestChat
pub fn new( request_id: RequestId, chat_is_channel: bool, ) -> KeyboardButtonRequestChat
Creates a new KeyboardButtonRequestChat.
Sourcepub fn chat_is_forum(self, value: bool) -> KeyboardButtonRequestChat
pub fn chat_is_forum(self, value: bool) -> KeyboardButtonRequestChat
Setter for chat_is_forum field.
Sourcepub fn chat_has_username(self, value: bool) -> KeyboardButtonRequestChat
pub fn chat_has_username(self, value: bool) -> KeyboardButtonRequestChat
Setter for chat_has_username field.
Sourcepub fn chat_is_created(self, value: bool) -> KeyboardButtonRequestChat
pub fn chat_is_created(self, value: bool) -> KeyboardButtonRequestChat
Setter for chat_is_created field.
Sourcepub fn user_administrator_rights(
self,
rights: ChatAdministratorRights,
) -> KeyboardButtonRequestChat
pub fn user_administrator_rights( self, rights: ChatAdministratorRights, ) -> KeyboardButtonRequestChat
Request a chat where the user has the specified administrator rights.
Sourcepub fn bot_administrator_rights(
self,
rights: ChatAdministratorRights,
) -> KeyboardButtonRequestChat
pub fn bot_administrator_rights( self, rights: ChatAdministratorRights, ) -> KeyboardButtonRequestChat
Request a chat where the bot has the specified administrator rights.
Sourcepub fn bot_is_member(self, value: bool) -> KeyboardButtonRequestChat
pub fn bot_is_member(self, value: bool) -> KeyboardButtonRequestChat
Setter for bot_is_member field.
Sourcepub fn request_title(self) -> KeyboardButtonRequestChat
pub fn request_title(self) -> KeyboardButtonRequestChat
Setter for request_title field.
Sourcepub fn request_username(self) -> KeyboardButtonRequestChat
pub fn request_username(self) -> KeyboardButtonRequestChat
Setter for request_username field.
Sourcepub fn request_photo(self) -> KeyboardButtonRequestChat
pub fn request_photo(self) -> KeyboardButtonRequestChat
Setter for request_photo field.