pub struct KeyboardButtonRequestUsers {
pub request_id: RequestId,
pub user_is_bot: Option<bool>,
pub user_is_premium: Option<bool>,
pub max_quantity: u8,
pub request_name: bool,
pub request_username: bool,
pub request_photo: bool,
}Expand description
This object defines the criteria used to request a suitable users.
Information about the selected users will be shared with the bot when the corresponding button is pressed. More about requesting users »
Fields
request_id: RequestIdIdentifier of the request, which will be received back in the
UsersShared object. Must be unique within the message.
user_is_bot: Option<bool>Pass true to request a bot, pass false to request a regular user. If
not specified, no additional restrictions are applied.
Pass true to request a premium user, pass false to request a
non-premium user. If not specified, no additional restrictions are
applied.
max_quantity: u8The maximum number of users to be selected; 1-10. Defaults to 1.
request_name: boolPass true to request the users’ first and last names
request_username: boolPass true to request the users’ username
request_photo: boolPass true to request the users’ photos
Implementations
Sourceimpl KeyboardButtonRequestUsers
impl KeyboardButtonRequestUsers
Sourcepub fn new(request_id: RequestId) -> KeyboardButtonRequestUsers
pub fn new(request_id: RequestId) -> KeyboardButtonRequestUsers
Creates a new KeyboardButtonRequestUsers.
Sourcepub fn user_is_bot(self, value: bool) -> KeyboardButtonRequestUsers
pub fn user_is_bot(self, value: bool) -> KeyboardButtonRequestUsers
Setter for user_is_bot field
Setter for user_is_premium field
Sourcepub fn max_quantity(self, value: u8) -> KeyboardButtonRequestUsers
pub fn max_quantity(self, value: u8) -> KeyboardButtonRequestUsers
Setter for max_quantity field, the value must be in the range 1..=10
Sourcepub fn request_name(self) -> KeyboardButtonRequestUsers
pub fn request_name(self) -> KeyboardButtonRequestUsers
Setter for request_name field
Sourcepub fn request_username(self) -> KeyboardButtonRequestUsers
pub fn request_username(self) -> KeyboardButtonRequestUsers
Setter for request_username field
Sourcepub fn request_photo(self) -> KeyboardButtonRequestUsers
pub fn request_photo(self) -> KeyboardButtonRequestUsers
Setter for request_photo field