pub struct KeyboardMarkup {
pub keyboard: Vec<Vec<KeyboardButton>>,
pub is_persistent: bool,
pub resize_keyboard: bool,
pub one_time_keyboard: bool,
pub input_field_placeholder: String,
pub selective: bool,
}Expand description
This object represents a custom keyboard with reply options (see Introduction to bots for details and examples).
Fields
keyboard: Vec<Vec<KeyboardButton>>Array of button rows, each represented by an Array of
KeyboardButton objects
is_persistent: boolRequests clients to always show the keyboard when the regular keyboard
is hidden. Defaults to false, in which case the custom keyboard
can be hidden and opened with a keyboard icon.
resize_keyboard: boolRequests clients to resize the keyboard vertically for optimal fit
(e.g., make the keyboard smaller if there are just two rows of
buttons). Defaults to false, in which case the custom keyboard is
always of the same height as the app’s standard keyboard.
one_time_keyboard: boolRequests clients to hide the keyboard as soon as it’s been used. The
keyboard will still be available, but clients will automatically
display the usual letter-keyboard in the chat – the user can press a
special button in the input field to see the custom keyboard again.
Defaults to false.
input_field_placeholder: StringThe placeholder to be shown in the input field when the keyboard is active; 1-64 characters.
selective: boolUse this parameter if you want to show the keyboard to specific users
only. Targets: 1) users that are @mentioned in the text of the
Message object; 2) if the bot’s message is a reply (has
reply_to_message_id), sender of the original message.
Example: A user requests to change the bot‘s language, bot replies to the request with a keyboard to select the new language. Other users in the group don’t see the keyboard.
Implementations
Sourceimpl KeyboardMarkup
impl KeyboardMarkup
pub fn new<K>(keyboard: K) -> KeyboardMarkup
pub fn append_row<R>(self, buttons: R) -> KeyboardMarkupwhere
R: IntoIterator<Item = KeyboardButton>,
pub fn append_to_row( self, index: usize, button: KeyboardButton, ) -> KeyboardMarkup
Sourcepub fn persistent(self) -> KeyboardMarkup
pub fn persistent(self) -> KeyboardMarkup
Sets is_persistent to true.
Sourcepub fn resize_keyboard(self) -> KeyboardMarkup
pub fn resize_keyboard(self) -> KeyboardMarkup
Sets resize_keyboard to true.
Sourcepub fn one_time_keyboard(self) -> KeyboardMarkup
pub fn one_time_keyboard(self) -> KeyboardMarkup
Sets one_time_keyboard to true.
pub fn input_field_placeholder<T>(self, val: T) -> KeyboardMarkup
Sourcepub fn selective(self) -> KeyboardMarkup
pub fn selective(self) -> KeyboardMarkup
Sets selective to true.