pub struct LabeledPrice {
pub label: String,
pub amount: u32,
}Expand description
This object represents a portion of the price for goods or services.
Fields
label: StringPortion label.
amount: u32Price of the product in the smallest units of the currency (integer,
not float/double). For example, for a price of US$ 1.45 pass
amount = 145. See the exp parameter in currencies.json, it shows
the number of digits past the decimal point for each currency (2
for the majority of currencies).
Implementations
Sourceimpl LabeledPrice
impl LabeledPrice
pub fn new<S>(label: S, amount: u32) -> LabeledPrice
pub fn label<S>(self, val: S) -> LabeledPrice
pub fn amount(self, val: u32) -> LabeledPrice