pub struct LinkPreviewOptions {
pub is_disabled: bool,
pub url: Option<String>,
pub prefer_small_media: bool,
pub prefer_large_media: bool,
pub show_above_text: bool,
}Expand description
Describes the options used for link preview generation.
Fields
is_disabled: booltrue, if the link preview is disabled
url: Option<String>URL to use for the link preview. If empty, then the first URL found in the message text will be used
prefer_small_media: booltrue, if the media in the link preview is suppposed to be shrunk;
ignored if the URL isn’t explicitly specified or media size change isn’t
supported for the preview
prefer_large_media: booltrue, if the media in the link preview is suppposed to be enlarged;
ignored if the URL isn’t explicitly specified or media size change isn’t
supported for the preview
show_above_text: booltrue, if the link preview must be shown above the message text;
otherwise, the link preview will be shown below the message text