pub struct Location {
pub longitude: f64,
pub latitude: f64,
pub horizontal_accuracy: Option<f64>,
pub live_period: Option<LivePeriod>,
pub heading: Option<u16>,
pub proximity_alert_radius: Option<u32>,
}Expand description
This object represents a point on the map.
Fields
longitude: f64Longitude as defined by sender.
latitude: f64Latitude as defined by sender.
horizontal_accuracy: Option<f64>The radius of uncertainty for the location, measured in meters; 0-1500
live_period: Option<LivePeriod>Time relative to the message sending date, during which the location can be updated, in seconds. For active live locations only.
heading: Option<u16>The direction in which user is moving, in degrees; 1-360. For active live locations only.
proximity_alert_radius: Option<u32>Maximum distance for proximity alerts about approaching another chat member, in meters. For sent live locations only.