pub struct MediaAnimation {
pub animation: Animation,
pub caption: Option<String>,
pub caption_entities: Vec<MessageEntity>,
pub show_caption_above_media: bool,
pub has_media_spoiler: bool,
}Fields
animation: AnimationMessage is an animation, information about the animation. For backward compatibility, when this field is set, the document field will also be set.
caption: Option<String>Caption for the animation, 0-1024 characters.
caption_entities: Vec<MessageEntity>For messages with a caption, special entities like usernames, URLs, bot commands, etc. that appear in the caption.
show_caption_above_media: booltrue, if the caption must be shown above the message media.
has_media_spoiler: booltrue, if the message media is covered by a spoiler animation.