pub struct MediaPhoto {
pub photo: Vec<PhotoSize>,
pub caption: Option<String>,
pub caption_entities: Vec<MessageEntity>,
pub show_caption_above_media: bool,
pub has_media_spoiler: bool,
pub media_group_id: Option<MediaGroupId>,
}Fields
photo: Vec<PhotoSize>Message is a photo, available sizes of the photo.
caption: Option<String>Caption for the photo, 0-1024 characters.
caption_entities: Vec<MessageEntity>For messages with a caption, special entities like usernames, URLs, bot commands, etc. that appear in the caption.
show_caption_above_media: booltrue, if the caption must be shown above the message media.
has_media_spoiler: booltrue, if the message media is covered by a spoiler animation.
media_group_id: Option<MediaGroupId>The unique identifier of a media message group this message belongs to.