pub struct MessageEntity {
pub kind: MessageEntityKind,
pub offset: usize,
pub length: usize,
}Expand description
This object represents one special entity in a text message.
For example, hashtags, usernames, URLs, etc.
Fields
kind: MessageEntityKindoffset: usizeOffset in UTF-16 code units to the start of the entity.
length: usizeLength of the entity in UTF-16 code units.
Implementations
Sourceimpl MessageEntity
impl MessageEntity
pub const fn new( kind: MessageEntityKind, offset: usize, length: usize, ) -> MessageEntity
Sourcepub const fn bold(offset: usize, length: usize) -> MessageEntity
pub const fn bold(offset: usize, length: usize) -> MessageEntity
Create a message entity representing a bold text.
Sourcepub const fn italic(offset: usize, length: usize) -> MessageEntity
pub const fn italic(offset: usize, length: usize) -> MessageEntity
Create a message entity representing an italic text.
Sourcepub const fn underline(offset: usize, length: usize) -> MessageEntity
pub const fn underline(offset: usize, length: usize) -> MessageEntity
Create a message entity representing an underline text.
Sourcepub const fn strikethrough(offset: usize, length: usize) -> MessageEntity
pub const fn strikethrough(offset: usize, length: usize) -> MessageEntity
Create a message entity representing a strikethrough text.
Sourcepub const fn spoiler(offset: usize, length: usize) -> MessageEntity
pub const fn spoiler(offset: usize, length: usize) -> MessageEntity
Create a message entity representing a spoiler text.
Sourcepub const fn code(offset: usize, length: usize) -> MessageEntity
pub const fn code(offset: usize, length: usize) -> MessageEntity
Create a message entity representing a monowidth text.
Sourcepub const fn pre(
language: Option<String>,
offset: usize,
length: usize,
) -> MessageEntity
pub const fn pre( language: Option<String>, offset: usize, length: usize, ) -> MessageEntity
Create a message entity representing a monowidth block.
Sourcepub const fn text_link(url: Url, offset: usize, length: usize) -> MessageEntity
pub const fn text_link(url: Url, offset: usize, length: usize) -> MessageEntity
Create a message entity representing a clickable text URL.
Sourcepub const fn text_mention(
user: User,
offset: usize,
length: usize,
) -> MessageEntity
pub const fn text_mention( user: User, offset: usize, length: usize, ) -> MessageEntity
Create a message entity representing a text mention.
Note
If you don’t have a complete User value, please use
MessageEntity::text_mention_id instead.
Sourcepub fn text_mention_id(
user_id: UserId,
offset: usize,
length: usize,
) -> MessageEntity
pub fn text_mention_id( user_id: UserId, offset: usize, length: usize, ) -> MessageEntity
Create a message entity representing a text link in the form of
tg://user/?id=... that mentions user with user_id.
Sourcepub const fn custom_emoji(
custom_emoji_id: CustomEmojiId,
offset: usize,
length: usize,
) -> MessageEntity
pub const fn custom_emoji( custom_emoji_id: CustomEmojiId, offset: usize, length: usize, ) -> MessageEntity
Create a message entity representing a custom emoji.
pub fn kind(self, val: MessageEntityKind) -> MessageEntity
pub const fn offset(self, val: usize) -> MessageEntity
pub const fn length(self, val: usize) -> MessageEntity