pub struct MessageReactionCountUpdated {
pub chat: Chat,
pub message_id: MessageId,
pub date: DateTime<Utc>,
pub reactions: Vec<ReactionCount>,
}Expand description
This object represents reaction changes on a message with anonymous reactions.
Fields
chat: ChatThe chat containing the message
message_id: MessageIdUnique message identifier inside the chat
date: DateTime<Utc>Date of the change in Unix time
reactions: Vec<ReactionCount>List of reactions that are present on the message