pub struct PaidMessagePriceChanged {
pub paid_message_star_count: u32,
}Expand description
Describes a service message about a change in the price of paid messages within a chat.
Fields
paid_message_star_count: u32The new number of Telegram Stars that must be paid by non-administrator users of the supergroup chat for each sent message