pub struct PreparedInlineMessage {
pub id: String,
pub expiration_date: DateTime<Utc>,
}Expand description
Describes an inline message to be sent by a user of a Mini App.
Fields
id: StringUnique identifier of the prepared message
expiration_date: DateTime<Utc>Expiration date of the prepared message, in Unix time. Expired prepared messages can no longer be used