ReplyParameters

Struct ReplyParameters 

pub struct ReplyParameters {
    pub message_id: MessageId,
    pub chat_id: Option<Recipient>,
    pub allow_sending_without_reply: Option<bool>,
    pub quote: Option<String>,
    pub quote_parse_mode: Option<String>,
    pub quote_entities: Option<Vec<MessageEntity>>,
    pub quote_position: Option<u32>,
}
Describes reply parameters for the message that is being sent.

Fields

message_id: MessageId

Identifier of the message that will be replied to in the current chat, or in the chat chat_id if it is specified

chat_id: Option<Recipient>

If the message to be replied to is from a different chat, unique identifier for the chat or username of the channel (in the format @channelusername). Not supported for messages sent on behalf of a business account.

allow_sending_without_reply: Option<bool>

Pass true if the message should be sent even if the specified message to be replied to is not found; can be used only for replies in the same chat and forum topic. Always false for replies in another chat or forum topic. Always true for messages sent on behalf of a business account.

quote: Option<String>

Quoted part of the message to be replied to; 0-1024 characters after entities parsing. The quote must be an exact substring of the message to be replied to, including bold, italic, underline, strikethrough, spoiler, and custom_emoji entities. The message will fail to send if the quote isn’t found in the original message.

quote_parse_mode: Option<String>

Mode for parsing entities in the quote. See formatting options for more details.

quote_entities: Option<Vec<MessageEntity>>

A JSON-serialized list of special entities that appear in the quote. It can be specified instead of quote_parse_mode.

quote_position: Option<u32>

Position of the quote in the original message in UTF-16 code units

Implementations

Source

impl ReplyParameters

pub fn new(message_id: MessageId) -> ReplyParameters

pub fn chat_id(self, chat_id: Recipient) -> ReplyParameters

Setter for the chat_id field

pub fn allow_sending_without_reply(self) -> ReplyParameters

Sets the allow_sending_without_reply_field to true

pub fn quote(self, quote: String) -> ReplyParameters

Setter for the quote field