pub struct SharedUser {
pub user_id: UserId,
pub first_name: Option<String>,
pub last_name: Option<String>,
pub username: Option<String>,
pub photo: Option<Vec<PhotoSize>>,
}Expand description
This object contains information about a user that was shared with the bot
using a KeyboardButtonRequestUsers button.
Fields
user_id: UserIdIdentifier of the shared user
first_name: Option<String>First name of the user, if it was requested by the bot
last_name: Option<String>Last name of the user, if it was requested by the bot
username: Option<String>Username of the user, if it was requested by the bot
photo: Option<Vec<PhotoSize>>Available sizes of the chat photo, if it was requested