pub struct StarTransaction {
pub id: TelegramTransactionId,
pub amount: u32,
pub nanostar_amount: Option<u32>,
pub date: DateTime<Utc>,
pub source: Option<TransactionPartner>,
pub receiver: Option<TransactionPartner>,
}Expand description
Describes a Telegram Star transaction.
Fields
id: TelegramTransactionIdUnique identifier of the transaction. Coincides with the identifer of
the original transaction for refund transactions. Coincides with
SuccessfulPayment::telegram_payment_charge_id for successful
incoming payments from users.
amount: u32Number of Telegram Stars transferred by the transaction.
nanostar_amount: Option<u32>The number of 1/1000000000 shares of Telegram Stars transferred by the transaction
date: DateTime<Utc>Date the transaction was created in Unix time.
source: Option<TransactionPartner>Source of an incoming transaction (e.g., a user purchasing goods or services, Fragment refunding a failed withdrawal). Only for incoming transactions.
receiver: Option<TransactionPartner>Receiver of an outgoing transaction (e.g., a user for a purchase refund, Fragment for a withdrawal). Only for outgoing transactions.