pub struct SwitchInlineQueryChosenChat {
pub query: Option<String>,
pub allow_user_chats: bool,
pub allow_bot_chats: bool,
pub allow_group_chats: bool,
pub allow_channel_chats: bool,
}Expand description
This object represents an inline button that switches the current user to inline mode in a chosen chat, with an optional default inline query.
Fields
query: Option<String>The default inline query to be inserted in the input field. If left empty, only the bot’s username will be inserted
allow_user_chats: boolTrue, if private chats with users can be chosen
allow_bot_chats: boolTrue, if private chats with bots can be chosen
allow_group_chats: boolTrue, if group and supergroup chats can be chosen
allow_channel_chats: boolTrue, if channel chats can be chosen