pub struct ThreadId(pub MessageId);Expand description
Reply thread identifier.
A message that isn’t a reply and other messages that reply to it directly or
indirectly through a reply chain constitute a reply thread. All messages
except the initial root message have an additional thread_id field that
is equal to the root message’s id.
In other words a thread id can be found recursively following
reply_to_message_id, until you find a message which does not reply to
anything, it’s id is the thread id.
For example:
lizard: Hi {id:17} <-------------+--------------+----+--------------+---------------------+
| | | | |
wizard: hewwo {id:18, reply: 17 -+, thread: 17 -+} | | |
| | |
lizard: I've been wondering [...] {id:19, reply: 17 -+, thread: 17 -+} <---+ |
| |
neushoorn: wait, did y'all know that [...] {id:20} <-----------------------)--------------)--+-----+
| | | |
wizard: so this is not an easy question, actually [...] {id:21, reply: 19 -+, thread: 17 -+} | |
+--------+ |
| |
wizard: everyone knows that, how did you not know that before?... {id:22, reply:20 -+, thread: 20 -+}Note that channel comments and forum topics, reuse threads for different meanings. For channel comments every comment (indirectly) replies to the channel post forwarded to the linked chat (i.e. the forwarded channel post is the root of the comments thread). For forum topics every message in a topic is in the same thread too (i.e. they (indirectly) reply to the start of the topic).
Tuple Fields
0: MessageIdIdentifier of the root message in a reply thread.