pub struct TransactionPartnerAffiliateProgram {
pub sponsor_user: Option<User>,
pub commission_per_mille: u32,
}Expand description
Describes the affiliate program that issued the affiliate commission received via this transaction.
Fields
sponsor_user: Option<User>Information about the bot that sponsored the affiliate program
commission_per_mille: u32The number of Telegram Stars received by the bot for each 1000 Telegram Stars received by the affiliate program sponsor from referred users