pub struct TransactionPartnerUserPaidMediaPayment {
pub affiliate: Option<AffiliateInfo>,
pub paid_media: Option<Vec<PaidMedia>>,
pub paid_media_payload: Option<String>,
}Fields
affiliate: Option<AffiliateInfo>Information about the affiliate that received a commission via this transaction
paid_media: Option<Vec<PaidMedia>>Information about the paid media bought by the user.
paid_media_payload: Option<String>Bot-specified paid media payload