pub struct UserId(pub u64);Expand description
Identifier of a user.
Tuple Fields
0: u64Implementations
Sourceimpl UserId
impl UserId
Sourcepub fn url(self) -> Url
pub fn url(self) -> Url
Returns an URL that links to the user with this id in the form of
tg://user/?id=<...>.
Sourcepub fn is_anonymous(self) -> bool
pub fn is_anonymous(self) -> bool
Returns true if this is the id of the special user used by telegram
bot API to denote an anonymous user that sends messages on behalf of
a group.
Sourcepub fn is_channel(self) -> bool
pub fn is_channel(self) -> bool
Returns true if this is the id of the special user used by telegram
bot API to denote an anonymous user that sends messages on behalf of
a channel.
Sourcepub fn is_telegram(self) -> bool
pub fn is_telegram(self) -> bool
Returns true if this is the id of the special user used by telegram
itself.
It is sometimes also used as a fallback, for example when a channel post
is automatically forwarded to a group, bots in a group will get a
message where from is the Telegram user.