pub struct Video {
pub file: FileMeta,
pub width: u32,
pub height: u32,
pub duration: Seconds,
pub thumbnail: Option<PhotoSize>,
pub cover: Option<Vec<PhotoSize>>,
pub start_timestamp: Option<Seconds>,
pub file_name: Option<String>,
pub mime_type: Option<Mime>,
}Expand description
This object represents a video file.
Fields
file: FileMetaMetadata of the video file.
width: u32Video width as defined by sender.
height: u32Video height as defined by sender.
duration: SecondsDuration of the video in seconds as defined by sender.
thumbnail: Option<PhotoSize>Video thumbnail.
cover: Option<Vec<PhotoSize>>Available sizes of the cover of the video in the message
start_timestamp: Option<Seconds>Timestamp in seconds from which the video will play in the message
file_name: Option<String>Original filename as defined by sender
mime_type: Option<Mime>Mime type of a file as defined by sender.