pub struct VideoChatParticipantsInvited {
pub users: Option<Vec<User>>,
}Expand description
This object represents a service message about new members invited to a video chat.
Fields
users: Option<Vec<User>>New members that were invited to the video chat