pub struct Voice {
pub file: FileMeta,
pub duration: Seconds,
pub mime_type: Option<Mime>,
}Expand description
This object represents a voice note.
Fields
file: FileMetaMetadata of the voice file.
duration: SecondsDuration of the audio in seconds as defined by sender.
mime_type: Option<Mime>MIME type of the file as defined by sender.