pub struct WriteAccessAllowed {
pub web_app_name: Option<String>,
pub from_request: Option<bool>,
pub from_attachment_menu: Option<bool>,
}Expand description
This object represents a service message about a user allowing a bot to write messages after adding the bot to the attachment menu or launching a Web App from a link.
Fields
web_app_name: Option<String>Name of the Web App which was launched from a link
from_request: Option<bool>true, if the access was granted after the user accepted an explicit
request from a Web App sent by the method requestWriteAccess
true, if the access was granted when the bot was added to the
attachment or side menu