CommandDescriptions

Struct CommandDescriptions 

pub struct CommandDescriptions<'a> { /* private fields */ }
Command descriptions that can be shown to the user (e.g. as a part of /help message)

Most of the time you don’t need to create this struct yourself as it’s returned from BotCommands::descriptions.

Implementations

Source

impl<'a> CommandDescriptions<'a>

pub const fn new(descriptions: &'a [CommandDescription<'a>]) -> Self

Creates new CommandDescriptions from a list of command descriptions.

pub fn global_description(self, global_description: &'a str) -> Self

Sets the global description of these commands.

pub fn username(self, bot_username: &'a str) -> Self

Sets the username of the bot.

After this method is called, returned instance of CommandDescriptions will append @bot_username to all commands. This is useful in groups, to disambiguate commands for different bots.

Examples
use teloxide_ng::utils::command::{CommandDescription, CommandDescriptions};

let descriptions = CommandDescriptions::new(&[
    CommandDescription {
        prefix: "/",
        command: "start",
        description: "start this bot",
        aliases: &[],
    },
    CommandDescription {
        prefix: "/",
        command: "help",
        description: "show this message",
        aliases: &[],
    },
]);

assert_eq!(descriptions.to_string(), "/start — start this bot\n/help — show this message");
assert_eq!(
    descriptions.username("username_of_the_bot").to_string(),
    "/start@username_of_the_bot — start this bot\n/help@username_of_the_bot — show this \
     message"
);
pub fn username_from_me(self, me: &'a Me) -> CommandDescriptions<'a>

Sets the username of the bot.

This is the same as username, but uses value returned from get_me method to get the username.

Examples found in repository?
examples/dispatching_features.rs (line 161)
145async fn simple_commands_handler(
146    cfg: ConfigParameters,
147    bot: Bot,
148    me: teloxide_ng::types::Me,
149    msg: Message,
150    cmd: SimpleCommand,
151) -> Result<(), teloxide_ng::RequestError> {
152    let text = match cmd {
153        SimpleCommand::Help => {
154            if msg.from.unwrap().id == cfg.bot_maintainer {
155                format!(
156                    "{}\n\n{}",
157                    SimpleCommand::descriptions(),
158                    MaintainerCommands::descriptions()
159                )
160            } else if msg.chat.is_group() || msg.chat.is_supergroup() {
161                SimpleCommand::descriptions().username_from_me(&me).to_string()
162            } else {
163                SimpleCommand::descriptions().to_string()
164            }
165        }
166        SimpleCommand::Maintainer => {
167            if msg.from.as_ref().unwrap().id == cfg.bot_maintainer {
168                "Maintainer is you!".into()
169            } else if let Some(username) = cfg.maintainer_username {
170                format!("Maintainer is @{username}")
171            } else {
172                format!("Maintainer ID is {}", cfg.bot_maintainer)
173            }
174        }
175        SimpleCommand::MyId => {
176            format!("{}", msg.from.unwrap().id)
177        }
178    };
179
180    bot.send_message(msg.chat.id, text).await?;
181
182    Ok(())
183}