RenderMessageTextHelper

Trait RenderMessageTextHelper 

pub trait RenderMessageTextHelper {
    // Required methods
    fn html_text(&self) -> Option<String>;
    fn markdown_text(&self) -> Option<String>;
    fn html_caption(&self) -> Option<String>;
    fn markdown_caption(&self) -> Option<String>;
}
Generates HTML and Markdown representations of text and captions in a Telegram message.

Required Methods

fn html_text(&self) -> Option<String>

Returns the HTML representation of the message text, if the message contains text. This method will parse the text and any entities (such as bold, italic, links, etc.) and return the HTML-formatted string.

fn markdown_text(&self) -> Option<String>

Returns the Markdown representation of the message text, if the message contains text. This method will parse the text and any entities (such as bold, italic, links, etc.) and return the Markdown-formatted string.

fn html_caption(&self) -> Option<String>

Returns the HTML representation of the message caption, if the message contains caption. This method will parse the caption and any entities (such as bold, italic, links, etc.) and return the HTML-formatted string.

fn markdown_caption(&self) -> Option<String>

Returns the Markdown representation of the message caption, if the message contains caption. This method will parse the caption and any entities (such as bold, italic, links, etc.) and return the Markdown-formatted string.

Implementors