pub struct Bot { /* private fields */ }Expand description
A requests sender.
This is the main type of the library, it allows to send requests to the Telegram Bot API and download files.
TBA methods
All TBA methods are located in the Requester impl for Bot. This
allows for opt-in behaviours using requester adaptors.
use teloxide_core_ng::prelude::*;
let bot = Bot::new("TOKEN");
dbg!(bot.get_me().await?);File download
In the similar way as with TBA methods, file downloading methods are located
in a trait — Download<'_>. See its documentation for more.
Clone cost
Bot::clone is relatively cheap, so if you need to share Bot, it’s
recommended to clone it, instead of wrapping it in Arc<_>.
Implementations
Sourceimpl Bot
Constructors
impl Bot
Constructors
Sourcepub fn new<S>(token: S) -> Bot ⓘ
pub fn new<S>(token: S) -> Bot ⓘ
Creates a new Bot with the specified token and the default
http-client.
Panics
If it cannot create reqwest::Client.
Sourcepub fn with_client<S>(token: S, client: Client) -> Bot ⓘ
pub fn with_client<S>(token: S, client: Client) -> Bot ⓘ
Creates a new Bot with the specified token and your
reqwest::Client.
Caution
Your custom client might not be configured correctly to be able to work in long time durations, see issue 223.
Sourcepub fn from_env() -> Bot ⓘ
pub fn from_env() -> Bot ⓘ
Creates a new Bot with the TELOXIDE_TOKEN & TELOXIDE_API_URL &
TELOXIDE_PROXY environmental variables (the bot’s token & the bot’s
API URL & the proxy) and the default reqwest::Client.
If TELOXIDE_API_URL doesn’t exist, returns to the default TBA URL.
This function passes the value of TELOXIDE_PROXY into
reqwest::Proxy::all, if it exists, otherwise returns the default
client.
Panics
- If cannot get the
TELOXIDE_TOKENenvironmental variable. - If
TELOXIDE_API_URLexists, but isn’t a correct URL. - If it cannot create
reqwest::Client.
Examples found in repository?
More examples
6async fn main() {
7 pretty_env_logger::init();
8 log::info!("Starting throw dice bot...");
9
10 let bot = Bot::from_env();
11
12 teloxide_ng::repl(bot, |bot: Bot, msg: Message| async move {
13 bot.send_dice(msg.chat.id).await?;
14 Ok(())
15 })
16 .await;
17}48async fn main() {
49 pretty_env_logger::init();
50 log::info!("Starting purchase bot...");
51
52 let bot = Bot::from_env();
53
54 Dispatcher::builder(bot, schema())
55 .dependencies(dptree::deps![InMemStorage::<State>::new()])
56 .enable_ctrlc_handler()
57 .build()
58 .dispatch()
59 .await;
60}24async fn main() -> Result<(), Box<dyn Error>> {
25 pretty_env_logger::init();
26 log::info!("Starting buttons bot...");
27
28 let bot = Bot::from_env();
29
30 let handler = dptree::entry()
31 .branch(Update::filter_message().endpoint(message_handler))
32 .branch(Update::filter_callback_query().endpoint(callback_handler))
33 .branch(Update::filter_inline_query().endpoint(inline_query_handler));
34
35 Dispatcher::builder(bot, handler).enable_ctrlc_handler().build().dispatch().await;
36 Ok(())
37}7async fn main() {
8 pretty_env_logger::init();
9 log::info!("Starting ngrok ping-pong bot...");
10
11 let bot = Bot::from_env();
12
13 let addr = ([127, 0, 0, 1], 8443).into();
14 let url = "Your HTTPS ngrok URL here. Get it by `ngrok http 8443`".parse().unwrap();
15 let listener = webhooks::axum(bot.clone(), webhooks::Options::new(addr, url))
16 .await
17 .expect("Couldn't setup webhook");
18
19 teloxide_ng::repl_with_listener(
20 bot,
21 |bot: Bot, msg: Message| async move {
22 bot.send_message(msg.chat.id, "pong").await?;
23 Ok(())
24 },
25 listener,
26 )
27 .await;
28}Sourcepub fn from_env_with_client(client: Client) -> Bot ⓘ
pub fn from_env_with_client(client: Client) -> Bot ⓘ
Creates a new Bot with the TELOXIDE_TOKEN environmental variable
(the bot’s token), TELOXIDE_API_URL environmental variable (the bot’s
API URL) and your reqwest::Client.
If TELOXIDE_API_URL doesn’t exist, returns to the default TBA URL.
Panics
- If cannot get the
TELOXIDE_TOKENenvironmental variable. - If
TELOXIDE_API_URLexists, but isn’t a correct URL.
Caution
Your custom client might not be configured correctly to be able to work in long time durations, see issue 223.
Sourcepub fn set_api_url(self, url: Url) -> Bot ⓘ
pub fn set_api_url(self, url: Url) -> Bot ⓘ
Sets a custom API URL.
For example, you can run your own TBA server and set its URL using this method.
Examples
use teloxide_core_ng::{
Bot,
requests::{Request, Requester},
};
let url = reqwest::Url::parse("https://localhost/tbas").unwrap();
let bot = Bot::new("TOKEN").set_api_url(url);
// From now all methods will use "https://localhost/tbas" as an API URL.
bot.get_me().awaitMulti-instance behaviour
This method only sets the URL for one bot instace, older clones are unaffected.
use teloxide_core_ng::Bot;
let bot = Bot::new("TOKEN");
let bot2 = bot.clone();
let bot = bot.set_api_url(reqwest::Url::parse("https://example.com/").unwrap());
assert_eq!(bot.api_url().as_str(), "https://example.com/");
assert_eq!(bot.clone().api_url().as_str(), "https://example.com/");
assert_ne!(bot2.api_url().as_str(), "https://example.com/");Trait Implementations
Sourceimpl Download for Bot
impl Download for Bot
Sourcetype Err<'dst> = DownloadError
type Err<'dst> = DownloadError
download_file.Sourcetype Fut<'dst> = Pin<Box<dyn Future<Output = Result<(), <Bot as Download>::Err<'dst>>> + Send + 'dst>>
type Fut<'dst> = Pin<Box<dyn Future<Output = Result<(), <Bot as Download>::Err<'dst>>> + Send + 'dst>>
download_file.Sourcetype StreamErr = Error
type StreamErr = Error
download_file_stream.Sourcetype Stream = Pin<Box<dyn Stream<Item = Result<Bytes, <Bot as Download>::StreamErr>> + Send>>
type Stream = Pin<Box<dyn Stream<Item = Result<Bytes, <Bot as Download>::StreamErr>> + Send>>
download_file_stream.Sourceimpl Requester for Bot
impl Requester for Bot
Sourcetype Err = RequestError
type Err = RequestError
type GetUpdates = JsonRequest<GetUpdates>
type SetWebhook = MultipartRequest<SetWebhook>
type DeleteWebhook = JsonRequest<DeleteWebhook>
type GetWebhookInfo = JsonRequest<GetWebhookInfo>
type GetMe = JsonRequest<GetMe>
type SendMessage = JsonRequest<SendMessage>
type SendMessageDraft = JsonRequest<SendMessageDraft>
type ForwardMessage = JsonRequest<ForwardMessage>
type ForwardMessages = JsonRequest<ForwardMessages>
type SendPhoto = MultipartRequest<SendPhoto>
type SendAudio = MultipartRequest<SendAudio>
type SendDocument = MultipartRequest<SendDocument>
type SendVideo = MultipartRequest<SendVideo>
type SendAnimation = MultipartRequest<SendAnimation>
type SendVoice = MultipartRequest<SendVoice>
type SendVideoNote = MultipartRequest<SendVideoNote>
type SendPaidMedia = MultipartRequest<SendPaidMedia>
type SendMediaGroup = MultipartRequest<SendMediaGroup>
type SendLocation = JsonRequest<SendLocation>
type EditMessageLiveLocation = JsonRequest<EditMessageLiveLocation>
type EditMessageLiveLocationInline = JsonRequest<EditMessageLiveLocationInline>
type StopMessageLiveLocation = JsonRequest<StopMessageLiveLocation>
type StopMessageLiveLocationInline = JsonRequest<StopMessageLiveLocationInline>
type EditMessageChecklist = JsonRequest<EditMessageChecklist>
type SendVenue = JsonRequest<SendVenue>
type SendContact = JsonRequest<SendContact>
type SendPoll = JsonRequest<SendPoll>
type SendChecklist = JsonRequest<SendChecklist>
type SendDice = JsonRequest<SendDice>
type SendChatAction = JsonRequest<SendChatAction>
type SetMessageReaction = JsonRequest<SetMessageReaction>
type GetUserProfilePhotos = JsonRequest<GetUserProfilePhotos>
type SetUserEmojiStatus = JsonRequest<SetUserEmojiStatus>
type GetFile = JsonRequest<GetFile>
type KickChatMember = JsonRequest<KickChatMember>
type BanChatMember = JsonRequest<BanChatMember>
type UnbanChatMember = JsonRequest<UnbanChatMember>
type RestrictChatMember = JsonRequest<RestrictChatMember>
type PromoteChatMember = JsonRequest<PromoteChatMember>
type SetChatAdministratorCustomTitle = JsonRequest<SetChatAdministratorCustomTitle>
type BanChatSenderChat = JsonRequest<BanChatSenderChat>
type UnbanChatSenderChat = JsonRequest<UnbanChatSenderChat>
type SetChatPermissions = JsonRequest<SetChatPermissions>
type ExportChatInviteLink = JsonRequest<ExportChatInviteLink>
type CreateChatInviteLink = JsonRequest<CreateChatInviteLink>
type EditChatInviteLink = JsonRequest<EditChatInviteLink>
type CreateChatSubscriptionInviteLink = JsonRequest<CreateChatSubscriptionInviteLink>
type EditChatSubscriptionInviteLink = JsonRequest<EditChatSubscriptionInviteLink>
type RevokeChatInviteLink = JsonRequest<RevokeChatInviteLink>
type ApproveChatJoinRequest = JsonRequest<ApproveChatJoinRequest>
type DeclineChatJoinRequest = JsonRequest<DeclineChatJoinRequest>
type SetChatPhoto = MultipartRequest<SetChatPhoto>
type DeleteChatPhoto = JsonRequest<DeleteChatPhoto>
type SetChatTitle = JsonRequest<SetChatTitle>
type SetChatDescription = JsonRequest<SetChatDescription>
type PinChatMessage = JsonRequest<PinChatMessage>
type UnpinChatMessage = JsonRequest<UnpinChatMessage>
type LeaveChat = JsonRequest<LeaveChat>
type GetChat = JsonRequest<GetChat>
type GetChatAdministrators = JsonRequest<GetChatAdministrators>
type GetChatMembersCount = JsonRequest<GetChatMembersCount>
type GetChatMemberCount = JsonRequest<GetChatMemberCount>
type GetChatMember = JsonRequest<GetChatMember>
type SetChatStickerSet = JsonRequest<SetChatStickerSet>
type DeleteChatStickerSet = JsonRequest<DeleteChatStickerSet>
type GetForumTopicIconStickers = JsonRequest<GetForumTopicIconStickers>
type CreateForumTopic = JsonRequest<CreateForumTopic>
type EditForumTopic = JsonRequest<EditForumTopic>
type CloseForumTopic = JsonRequest<CloseForumTopic>
type ReopenForumTopic = JsonRequest<ReopenForumTopic>
type DeleteForumTopic = JsonRequest<DeleteForumTopic>
type UnpinAllForumTopicMessages = JsonRequest<UnpinAllForumTopicMessages>
type EditGeneralForumTopic = JsonRequest<EditGeneralForumTopic>
type CloseGeneralForumTopic = JsonRequest<CloseGeneralForumTopic>
type ReopenGeneralForumTopic = JsonRequest<ReopenGeneralForumTopic>
type HideGeneralForumTopic = JsonRequest<HideGeneralForumTopic>
type UnhideGeneralForumTopic = JsonRequest<UnhideGeneralForumTopic>
type UnpinAllGeneralForumTopicMessages = JsonRequest<UnpinAllGeneralForumTopicMessages>
type AnswerCallbackQuery = JsonRequest<AnswerCallbackQuery>
type GetUserChatBoosts = JsonRequest<GetUserChatBoosts>
type SetMyCommands = JsonRequest<SetMyCommands>
type GetBusinessConnection = JsonRequest<GetBusinessConnection>
type GetMyCommands = JsonRequest<GetMyCommands>
type SetMyName = JsonRequest<SetMyName>
type GetMyName = JsonRequest<GetMyName>
type SetMyDescription = JsonRequest<SetMyDescription>
type GetMyDescription = JsonRequest<GetMyDescription>
type SetMyShortDescription = JsonRequest<SetMyShortDescription>
type GetMyShortDescription = JsonRequest<GetMyShortDescription>
type SetChatMenuButton = JsonRequest<SetChatMenuButton>
type GetChatMenuButton = JsonRequest<GetChatMenuButton>
type SetMyDefaultAdministratorRights = JsonRequest<SetMyDefaultAdministratorRights>
type GetMyDefaultAdministratorRights = JsonRequest<GetMyDefaultAdministratorRights>
type DeleteMyCommands = JsonRequest<DeleteMyCommands>
type AnswerInlineQuery = JsonRequest<AnswerInlineQuery>
type AnswerWebAppQuery = JsonRequest<AnswerWebAppQuery>
type SavePreparedInlineMessage = JsonRequest<SavePreparedInlineMessage>
type EditMessageText = JsonRequest<EditMessageText>
type EditMessageTextInline = JsonRequest<EditMessageTextInline>
type EditMessageCaption = JsonRequest<EditMessageCaption>
type EditMessageCaptionInline = JsonRequest<EditMessageCaptionInline>
type EditMessageMedia = MultipartRequest<EditMessageMedia>
type EditMessageMediaInline = MultipartRequest<EditMessageMediaInline>
type EditMessageReplyMarkup = JsonRequest<EditMessageReplyMarkup>
type EditMessageReplyMarkupInline = JsonRequest<EditMessageReplyMarkupInline>
type StopPoll = JsonRequest<StopPoll>
type ApproveSuggestedPost = JsonRequest<ApproveSuggestedPost>
type DeclineSuggestedPost = JsonRequest<DeclineSuggestedPost>
type DeleteMessage = JsonRequest<DeleteMessage>
type DeleteMessages = JsonRequest<DeleteMessages>
type SendSticker = MultipartRequest<SendSticker>
type GetStickerSet = JsonRequest<GetStickerSet>
type GetCustomEmojiStickers = JsonRequest<GetCustomEmojiStickers>
type UploadStickerFile = MultipartRequest<UploadStickerFile>
type CreateNewStickerSet = MultipartRequest<CreateNewStickerSet>
type AddStickerToSet = MultipartRequest<AddStickerToSet>
type SetStickerPositionInSet = JsonRequest<SetStickerPositionInSet>
type DeleteStickerFromSet = JsonRequest<DeleteStickerFromSet>
type ReplaceStickerInSet = JsonRequest<ReplaceStickerInSet>
type SetStickerSetThumbnail = MultipartRequest<SetStickerSetThumbnail>
type SetCustomEmojiStickerSetThumbnail = JsonRequest<SetCustomEmojiStickerSetThumbnail>
type SetStickerSetTitle = JsonRequest<SetStickerSetTitle>
type DeleteStickerSet = JsonRequest<DeleteStickerSet>
type SetStickerEmojiList = JsonRequest<SetStickerEmojiList>
type SetStickerKeywords = JsonRequest<SetStickerKeywords>
type SetStickerMaskPosition = JsonRequest<SetStickerMaskPosition>
type GetAvailableGifts = JsonRequest<GetAvailableGifts>
type SendGift = JsonRequest<SendGift>
type SendGiftChat = JsonRequest<SendGiftChat>
type GiftPremiumSubscription = JsonRequest<GiftPremiumSubscription>
type VerifyUser = JsonRequest<VerifyUser>
type VerifyChat = JsonRequest<VerifyChat>
type RemoveUserVerification = JsonRequest<RemoveUserVerification>
type RemoveChatVerification = JsonRequest<RemoveChatVerification>
type ReadBusinessMessage = JsonRequest<ReadBusinessMessage>
type DeleteBusinessMessages = JsonRequest<DeleteBusinessMessages>
type SetBusinessAccountName = JsonRequest<SetBusinessAccountName>
type SetBusinessAccountUsername = JsonRequest<SetBusinessAccountUsername>
type SetBusinessAccountBio = JsonRequest<SetBusinessAccountBio>
type SetBusinessAccountProfilePhoto = JsonRequest<SetBusinessAccountProfilePhoto>
type RemoveBusinessAccountProfilePhoto = JsonRequest<RemoveBusinessAccountProfilePhoto>
type SetBusinessAccountGiftSettings = JsonRequest<SetBusinessAccountGiftSettings>
type GetBusinessAccountStarBalance = JsonRequest<GetBusinessAccountStarBalance>
type TransferBusinessAccountStars = JsonRequest<TransferBusinessAccountStars>
type GetBusinessAccountGifts = JsonRequest<GetBusinessAccountGifts>
type GetUserGifts = JsonRequest<GetUserGifts>
type GetChatGifts = JsonRequest<GetChatGifts>
type ConvertGiftToStars = JsonRequest<ConvertGiftToStars>
type UpgradeGift = JsonRequest<UpgradeGift>
type TransferGift = JsonRequest<TransferGift>
type PostStory = JsonRequest<PostStory>
type RepostStory = JsonRequest<RepostStory>
type EditStory = JsonRequest<EditStory>
type DeleteStory = JsonRequest<DeleteStory>
type SendInvoice = JsonRequest<SendInvoice>
type CreateInvoiceLink = JsonRequest<CreateInvoiceLink>
type AnswerShippingQuery = JsonRequest<AnswerShippingQuery>
type AnswerPreCheckoutQuery = JsonRequest<AnswerPreCheckoutQuery>
type GetMyStarBalance = JsonRequest<GetMyStarBalance>
type GetStarTransactions = JsonRequest<GetStarTransactions>
type RefundStarPayment = JsonRequest<RefundStarPayment>
type EditUserStarSubscription = JsonRequest<EditUserStarSubscription>
type SetPassportDataErrors = JsonRequest<SetPassportDataErrors>
type SendGame = JsonRequest<SendGame>
type SetGameScore = JsonRequest<SetGameScore>
type SetGameScoreInline = JsonRequest<SetGameScoreInline>
type GetGameHighScores = JsonRequest<GetGameHighScores>
type LogOut = JsonRequest<LogOut>
type Close = JsonRequest<Close>
type CopyMessage = JsonRequest<CopyMessage>
type CopyMessages = JsonRequest<CopyMessages>
type UnpinAllChatMessages = JsonRequest<UnpinAllChatMessages>
Sourcefn get_updates(&self) -> <Bot as Requester>::GetUpdates ⓘ
fn get_updates(&self) -> <Bot as Requester>::GetUpdates ⓘ
GetUpdates.Sourcefn set_webhook(&self, url: Url) -> <Bot as Requester>::SetWebhook ⓘ
fn set_webhook(&self, url: Url) -> <Bot as Requester>::SetWebhook ⓘ
SetWebhook.Sourcefn delete_webhook(&self) -> <Bot as Requester>::DeleteWebhook ⓘ
fn delete_webhook(&self) -> <Bot as Requester>::DeleteWebhook ⓘ
DeleteWebhook.Sourcefn get_webhook_info(&self) -> <Bot as Requester>::GetWebhookInfo ⓘ
fn get_webhook_info(&self) -> <Bot as Requester>::GetWebhookInfo ⓘ
GetWebhookInfo.Sourcefn send_message<C, T>(
&self,
chat_id: C,
text: T,
) -> <Bot as Requester>::SendMessage ⓘ
fn send_message<C, T>( &self, chat_id: C, text: T, ) -> <Bot as Requester>::SendMessage ⓘ
SendMessage.Sourcefn send_message_draft<C, T>(
&self,
chat_id: C,
draft_id: u32,
text: T,
) -> <Bot as Requester>::SendMessageDraft ⓘ
fn send_message_draft<C, T>( &self, chat_id: C, draft_id: u32, text: T, ) -> <Bot as Requester>::SendMessageDraft ⓘ
SendMessageDraft.Sourcefn forward_message<C, F>(
&self,
chat_id: C,
from_chat_id: F,
message_id: MessageId,
) -> <Bot as Requester>::ForwardMessage ⓘ
fn forward_message<C, F>( &self, chat_id: C, from_chat_id: F, message_id: MessageId, ) -> <Bot as Requester>::ForwardMessage ⓘ
ForwardMessage.Sourcefn forward_messages<C, F, M>(
&self,
chat_id: C,
from_chat_id: F,
message_ids: M,
) -> <Bot as Requester>::ForwardMessages ⓘ
fn forward_messages<C, F, M>( &self, chat_id: C, from_chat_id: F, message_ids: M, ) -> <Bot as Requester>::ForwardMessages ⓘ
ForwardMessages.Sourcefn send_photo<C>(
&self,
chat_id: C,
photo: InputFile,
) -> <Bot as Requester>::SendPhoto ⓘ
fn send_photo<C>( &self, chat_id: C, photo: InputFile, ) -> <Bot as Requester>::SendPhoto ⓘ
SendPhoto.Sourcefn send_audio<C>(
&self,
chat_id: C,
audio: InputFile,
) -> <Bot as Requester>::SendAudio ⓘ
fn send_audio<C>( &self, chat_id: C, audio: InputFile, ) -> <Bot as Requester>::SendAudio ⓘ
SendAudio.Sourcefn send_document<C>(
&self,
chat_id: C,
document: InputFile,
) -> <Bot as Requester>::SendDocument ⓘ
fn send_document<C>( &self, chat_id: C, document: InputFile, ) -> <Bot as Requester>::SendDocument ⓘ
SendDocument.Sourcefn send_video<C>(
&self,
chat_id: C,
video: InputFile,
) -> <Bot as Requester>::SendVideo ⓘ
fn send_video<C>( &self, chat_id: C, video: InputFile, ) -> <Bot as Requester>::SendVideo ⓘ
SendVideo.Sourcefn send_animation<C>(
&self,
chat_id: C,
animation: InputFile,
) -> <Bot as Requester>::SendAnimation ⓘ
fn send_animation<C>( &self, chat_id: C, animation: InputFile, ) -> <Bot as Requester>::SendAnimation ⓘ
SendAnimation.Sourcefn send_voice<C>(
&self,
chat_id: C,
voice: InputFile,
) -> <Bot as Requester>::SendVoice ⓘ
fn send_voice<C>( &self, chat_id: C, voice: InputFile, ) -> <Bot as Requester>::SendVoice ⓘ
SendVoice.Sourcefn send_video_note<C>(
&self,
chat_id: C,
video_note: InputFile,
) -> <Bot as Requester>::SendVideoNote ⓘ
fn send_video_note<C>( &self, chat_id: C, video_note: InputFile, ) -> <Bot as Requester>::SendVideoNote ⓘ
SendVideoNote.Sourcefn send_paid_media<C, M>(
&self,
chat_id: C,
star_count: u32,
media: M,
) -> <Bot as Requester>::SendPaidMedia ⓘ
fn send_paid_media<C, M>( &self, chat_id: C, star_count: u32, media: M, ) -> <Bot as Requester>::SendPaidMedia ⓘ
SendPaidMedia.Sourcefn send_media_group<C, M>(
&self,
chat_id: C,
media: M,
) -> <Bot as Requester>::SendMediaGroup ⓘ
fn send_media_group<C, M>( &self, chat_id: C, media: M, ) -> <Bot as Requester>::SendMediaGroup ⓘ
SendMediaGroup.Sourcefn send_location<C>(
&self,
chat_id: C,
latitude: f64,
longitude: f64,
) -> <Bot as Requester>::SendLocation ⓘ
fn send_location<C>( &self, chat_id: C, latitude: f64, longitude: f64, ) -> <Bot as Requester>::SendLocation ⓘ
SendLocation.Sourcefn edit_message_live_location<C>(
&self,
chat_id: C,
message_id: MessageId,
latitude: f64,
longitude: f64,
) -> <Bot as Requester>::EditMessageLiveLocation ⓘ
fn edit_message_live_location<C>( &self, chat_id: C, message_id: MessageId, latitude: f64, longitude: f64, ) -> <Bot as Requester>::EditMessageLiveLocation ⓘ
EditMessageLiveLocation.Sourcefn edit_message_live_location_inline<I>(
&self,
inline_message_id: I,
latitude: f64,
longitude: f64,
) -> <Bot as Requester>::EditMessageLiveLocationInline ⓘ
fn edit_message_live_location_inline<I>( &self, inline_message_id: I, latitude: f64, longitude: f64, ) -> <Bot as Requester>::EditMessageLiveLocationInline ⓘ
EditMessageLiveLocationInline.Sourcefn stop_message_live_location<C>(
&self,
chat_id: C,
message_id: MessageId,
) -> <Bot as Requester>::StopMessageLiveLocation ⓘ
fn stop_message_live_location<C>( &self, chat_id: C, message_id: MessageId, ) -> <Bot as Requester>::StopMessageLiveLocation ⓘ
StopMessageLiveLocation.Sourcefn stop_message_live_location_inline<I>(
&self,
inline_message_id: I,
) -> <Bot as Requester>::StopMessageLiveLocationInline ⓘ
fn stop_message_live_location_inline<I>( &self, inline_message_id: I, ) -> <Bot as Requester>::StopMessageLiveLocationInline ⓘ
StopMessageLiveLocationInline.Sourcefn edit_message_checklist<C>(
&self,
business_connection_id: BusinessConnectionId,
chat_id: C,
message_id: MessageId,
checklist: InputChecklist,
) -> <Bot as Requester>::EditMessageChecklist ⓘ
fn edit_message_checklist<C>( &self, business_connection_id: BusinessConnectionId, chat_id: C, message_id: MessageId, checklist: InputChecklist, ) -> <Bot as Requester>::EditMessageChecklist ⓘ
EditMessageChecklist.Sourcefn send_venue<C, T, A>(
&self,
chat_id: C,
latitude: f64,
longitude: f64,
title: T,
address: A,
) -> <Bot as Requester>::SendVenue ⓘ
fn send_venue<C, T, A>( &self, chat_id: C, latitude: f64, longitude: f64, title: T, address: A, ) -> <Bot as Requester>::SendVenue ⓘ
SendVenue.Sourcefn send_contact<C, P, F>(
&self,
chat_id: C,
phone_number: P,
first_name: F,
) -> <Bot as Requester>::SendContact ⓘ
fn send_contact<C, P, F>( &self, chat_id: C, phone_number: P, first_name: F, ) -> <Bot as Requester>::SendContact ⓘ
SendContact.Sourcefn send_poll<C, Q, O>(
&self,
chat_id: C,
question: Q,
options: O,
) -> <Bot as Requester>::SendPoll ⓘ
fn send_poll<C, Q, O>( &self, chat_id: C, question: Q, options: O, ) -> <Bot as Requester>::SendPoll ⓘ
SendPoll.Sourcefn send_checklist<C>(
&self,
business_connection_id: BusinessConnectionId,
chat_id: C,
checklist: InputChecklist,
) -> <Bot as Requester>::SendChecklist ⓘ
fn send_checklist<C>( &self, business_connection_id: BusinessConnectionId, chat_id: C, checklist: InputChecklist, ) -> <Bot as Requester>::SendChecklist ⓘ
SendChecklist.Sourcefn send_dice<C>(&self, chat_id: C) -> <Bot as Requester>::SendDice ⓘ
fn send_dice<C>(&self, chat_id: C) -> <Bot as Requester>::SendDice ⓘ
SendDice.Sourcefn send_chat_action<C>(
&self,
chat_id: C,
action: ChatAction,
) -> <Bot as Requester>::SendChatAction ⓘ
fn send_chat_action<C>( &self, chat_id: C, action: ChatAction, ) -> <Bot as Requester>::SendChatAction ⓘ
SendChatAction.Sourcefn set_message_reaction<C>(
&self,
chat_id: C,
message_id: MessageId,
) -> <Bot as Requester>::SetMessageReaction ⓘ
fn set_message_reaction<C>( &self, chat_id: C, message_id: MessageId, ) -> <Bot as Requester>::SetMessageReaction ⓘ
SetMessageReaction.Sourcefn get_user_profile_photos(
&self,
user_id: UserId,
) -> <Bot as Requester>::GetUserProfilePhotos ⓘ
fn get_user_profile_photos( &self, user_id: UserId, ) -> <Bot as Requester>::GetUserProfilePhotos ⓘ
GetUserProfilePhotos.Sourcefn set_user_emoji_status(
&self,
user_id: UserId,
) -> <Bot as Requester>::SetUserEmojiStatus ⓘ
fn set_user_emoji_status( &self, user_id: UserId, ) -> <Bot as Requester>::SetUserEmojiStatus ⓘ
SetUserEmojiStatus.Sourcefn get_file(&self, file_id: FileId) -> <Bot as Requester>::GetFile ⓘ
fn get_file(&self, file_id: FileId) -> <Bot as Requester>::GetFile ⓘ
GetFile.Sourcefn kick_chat_member<C>(
&self,
chat_id: C,
user_id: UserId,
) -> <Bot as Requester>::KickChatMember ⓘ
fn kick_chat_member<C>( &self, chat_id: C, user_id: UserId, ) -> <Bot as Requester>::KickChatMember ⓘ
KickChatMember.Sourcefn ban_chat_member<C>(
&self,
chat_id: C,
user_id: UserId,
) -> <Bot as Requester>::BanChatMember ⓘ
fn ban_chat_member<C>( &self, chat_id: C, user_id: UserId, ) -> <Bot as Requester>::BanChatMember ⓘ
BanChatMember.Sourcefn unban_chat_member<C>(
&self,
chat_id: C,
user_id: UserId,
) -> <Bot as Requester>::UnbanChatMember ⓘ
fn unban_chat_member<C>( &self, chat_id: C, user_id: UserId, ) -> <Bot as Requester>::UnbanChatMember ⓘ
UnbanChatMember.Sourcefn restrict_chat_member<C>(
&self,
chat_id: C,
user_id: UserId,
permissions: ChatPermissions,
) -> <Bot as Requester>::RestrictChatMember ⓘ
fn restrict_chat_member<C>( &self, chat_id: C, user_id: UserId, permissions: ChatPermissions, ) -> <Bot as Requester>::RestrictChatMember ⓘ
RestrictChatMember.Sourcefn promote_chat_member<C>(
&self,
chat_id: C,
user_id: UserId,
) -> <Bot as Requester>::PromoteChatMember ⓘ
fn promote_chat_member<C>( &self, chat_id: C, user_id: UserId, ) -> <Bot as Requester>::PromoteChatMember ⓘ
PromoteChatMember.Sourcefn set_chat_administrator_custom_title<Ch, Cu>(
&self,
chat_id: Ch,
user_id: UserId,
custom_title: Cu,
) -> <Bot as Requester>::SetChatAdministratorCustomTitle ⓘ
fn set_chat_administrator_custom_title<Ch, Cu>( &self, chat_id: Ch, user_id: UserId, custom_title: Cu, ) -> <Bot as Requester>::SetChatAdministratorCustomTitle ⓘ
SetChatAdministratorCustomTitle.Sourcefn ban_chat_sender_chat<C, S>(
&self,
chat_id: C,
sender_chat_id: S,
) -> <Bot as Requester>::BanChatSenderChat ⓘ
fn ban_chat_sender_chat<C, S>( &self, chat_id: C, sender_chat_id: S, ) -> <Bot as Requester>::BanChatSenderChat ⓘ
BanChatSenderChat.Sourcefn unban_chat_sender_chat<C, S>(
&self,
chat_id: C,
sender_chat_id: S,
) -> <Bot as Requester>::UnbanChatSenderChat ⓘ
fn unban_chat_sender_chat<C, S>( &self, chat_id: C, sender_chat_id: S, ) -> <Bot as Requester>::UnbanChatSenderChat ⓘ
UnbanChatSenderChat.Sourcefn set_chat_permissions<C>(
&self,
chat_id: C,
permissions: ChatPermissions,
) -> <Bot as Requester>::SetChatPermissions ⓘ
fn set_chat_permissions<C>( &self, chat_id: C, permissions: ChatPermissions, ) -> <Bot as Requester>::SetChatPermissions ⓘ
SetChatPermissions.Sourcefn export_chat_invite_link<C>(
&self,
chat_id: C,
) -> <Bot as Requester>::ExportChatInviteLink ⓘ
fn export_chat_invite_link<C>( &self, chat_id: C, ) -> <Bot as Requester>::ExportChatInviteLink ⓘ
ExportChatInviteLink.Sourcefn create_chat_invite_link<C>(
&self,
chat_id: C,
) -> <Bot as Requester>::CreateChatInviteLink ⓘ
fn create_chat_invite_link<C>( &self, chat_id: C, ) -> <Bot as Requester>::CreateChatInviteLink ⓘ
CreateChatInviteLink.Sourcefn edit_chat_invite_link<C, I>(
&self,
chat_id: C,
invite_link: I,
) -> <Bot as Requester>::EditChatInviteLink ⓘ
fn edit_chat_invite_link<C, I>( &self, chat_id: C, invite_link: I, ) -> <Bot as Requester>::EditChatInviteLink ⓘ
EditChatInviteLink.Sourcefn create_chat_subscription_invite_link<C>(
&self,
chat_id: C,
subscription_period: Seconds,
subscription_price: u32,
) -> <Bot as Requester>::CreateChatSubscriptionInviteLink ⓘ
fn create_chat_subscription_invite_link<C>( &self, chat_id: C, subscription_period: Seconds, subscription_price: u32, ) -> <Bot as Requester>::CreateChatSubscriptionInviteLink ⓘ
CreateChatSubscriptionInviteLink.Sourcefn edit_chat_subscription_invite_link<C, I>(
&self,
chat_id: C,
invite_link: I,
) -> <Bot as Requester>::EditChatSubscriptionInviteLink ⓘ
fn edit_chat_subscription_invite_link<C, I>( &self, chat_id: C, invite_link: I, ) -> <Bot as Requester>::EditChatSubscriptionInviteLink ⓘ
EditChatSubscriptionInviteLink.Sourcefn revoke_chat_invite_link<C, I>(
&self,
chat_id: C,
invite_link: I,
) -> <Bot as Requester>::RevokeChatInviteLink ⓘ
fn revoke_chat_invite_link<C, I>( &self, chat_id: C, invite_link: I, ) -> <Bot as Requester>::RevokeChatInviteLink ⓘ
RevokeChatInviteLink.Sourcefn approve_chat_join_request<C>(
&self,
chat_id: C,
user_id: UserId,
) -> <Bot as Requester>::ApproveChatJoinRequest ⓘ
fn approve_chat_join_request<C>( &self, chat_id: C, user_id: UserId, ) -> <Bot as Requester>::ApproveChatJoinRequest ⓘ
ApproveChatJoinRequest.Sourcefn decline_chat_join_request<C>(
&self,
chat_id: C,
user_id: UserId,
) -> <Bot as Requester>::DeclineChatJoinRequest ⓘ
fn decline_chat_join_request<C>( &self, chat_id: C, user_id: UserId, ) -> <Bot as Requester>::DeclineChatJoinRequest ⓘ
DeclineChatJoinRequest.Sourcefn set_chat_photo<C>(
&self,
chat_id: C,
photo: InputFile,
) -> <Bot as Requester>::SetChatPhoto ⓘ
fn set_chat_photo<C>( &self, chat_id: C, photo: InputFile, ) -> <Bot as Requester>::SetChatPhoto ⓘ
SetChatPhoto.Sourcefn delete_chat_photo<C>(
&self,
chat_id: C,
) -> <Bot as Requester>::DeleteChatPhoto ⓘ
fn delete_chat_photo<C>( &self, chat_id: C, ) -> <Bot as Requester>::DeleteChatPhoto ⓘ
DeleteChatPhoto.Sourcefn set_chat_title<C, T>(
&self,
chat_id: C,
title: T,
) -> <Bot as Requester>::SetChatTitle ⓘ
fn set_chat_title<C, T>( &self, chat_id: C, title: T, ) -> <Bot as Requester>::SetChatTitle ⓘ
SetChatTitle.Sourcefn set_chat_description<C>(
&self,
chat_id: C,
) -> <Bot as Requester>::SetChatDescription ⓘ
fn set_chat_description<C>( &self, chat_id: C, ) -> <Bot as Requester>::SetChatDescription ⓘ
SetChatDescription.Sourcefn pin_chat_message<C>(
&self,
chat_id: C,
message_id: MessageId,
) -> <Bot as Requester>::PinChatMessage ⓘ
fn pin_chat_message<C>( &self, chat_id: C, message_id: MessageId, ) -> <Bot as Requester>::PinChatMessage ⓘ
PinChatMessage.Sourcefn unpin_chat_message<C>(
&self,
chat_id: C,
) -> <Bot as Requester>::UnpinChatMessage ⓘ
fn unpin_chat_message<C>( &self, chat_id: C, ) -> <Bot as Requester>::UnpinChatMessage ⓘ
UnpinChatMessage.Sourcefn leave_chat<C>(&self, chat_id: C) -> <Bot as Requester>::LeaveChat ⓘ
fn leave_chat<C>(&self, chat_id: C) -> <Bot as Requester>::LeaveChat ⓘ
LeaveChat.Sourcefn get_chat<C>(&self, chat_id: C) -> <Bot as Requester>::GetChat ⓘ
fn get_chat<C>(&self, chat_id: C) -> <Bot as Requester>::GetChat ⓘ
GetChat.Sourcefn get_chat_administrators<C>(
&self,
chat_id: C,
) -> <Bot as Requester>::GetChatAdministrators ⓘ
fn get_chat_administrators<C>( &self, chat_id: C, ) -> <Bot as Requester>::GetChatAdministrators ⓘ
GetChatAdministrators.Sourcefn get_chat_members_count<C>(
&self,
chat_id: C,
) -> <Bot as Requester>::GetChatMembersCount ⓘ
fn get_chat_members_count<C>( &self, chat_id: C, ) -> <Bot as Requester>::GetChatMembersCount ⓘ
GetChatMembersCount.Sourcefn get_chat_member_count<C>(
&self,
chat_id: C,
) -> <Bot as Requester>::GetChatMemberCount ⓘ
fn get_chat_member_count<C>( &self, chat_id: C, ) -> <Bot as Requester>::GetChatMemberCount ⓘ
GetChatMemberCount.Sourcefn get_chat_member<C>(
&self,
chat_id: C,
user_id: UserId,
) -> <Bot as Requester>::GetChatMember ⓘ
fn get_chat_member<C>( &self, chat_id: C, user_id: UserId, ) -> <Bot as Requester>::GetChatMember ⓘ
GetChatMember.Sourcefn set_chat_sticker_set<C, S>(
&self,
chat_id: C,
sticker_set_name: S,
) -> <Bot as Requester>::SetChatStickerSet ⓘ
fn set_chat_sticker_set<C, S>( &self, chat_id: C, sticker_set_name: S, ) -> <Bot as Requester>::SetChatStickerSet ⓘ
SetChatStickerSet.Sourcefn delete_chat_sticker_set<C>(
&self,
chat_id: C,
) -> <Bot as Requester>::DeleteChatStickerSet ⓘ
fn delete_chat_sticker_set<C>( &self, chat_id: C, ) -> <Bot as Requester>::DeleteChatStickerSet ⓘ
DeleteChatStickerSet.Sourcefn get_forum_topic_icon_stickers(
&self,
) -> <Bot as Requester>::GetForumTopicIconStickers ⓘ
fn get_forum_topic_icon_stickers( &self, ) -> <Bot as Requester>::GetForumTopicIconStickers ⓘ
GetForumTopicIconStickers.Sourcefn create_forum_topic<C, N>(
&self,
chat_id: C,
name: N,
) -> <Bot as Requester>::CreateForumTopic ⓘ
fn create_forum_topic<C, N>( &self, chat_id: C, name: N, ) -> <Bot as Requester>::CreateForumTopic ⓘ
CreateForumTopic.Sourcefn edit_forum_topic<C>(
&self,
chat_id: C,
message_thread_id: ThreadId,
) -> <Bot as Requester>::EditForumTopic ⓘ
fn edit_forum_topic<C>( &self, chat_id: C, message_thread_id: ThreadId, ) -> <Bot as Requester>::EditForumTopic ⓘ
EditForumTopic.Sourcefn close_forum_topic<C>(
&self,
chat_id: C,
message_thread_id: ThreadId,
) -> <Bot as Requester>::CloseForumTopic ⓘ
fn close_forum_topic<C>( &self, chat_id: C, message_thread_id: ThreadId, ) -> <Bot as Requester>::CloseForumTopic ⓘ
CloseForumTopic.Sourcefn reopen_forum_topic<C>(
&self,
chat_id: C,
message_thread_id: ThreadId,
) -> <Bot as Requester>::ReopenForumTopic ⓘ
fn reopen_forum_topic<C>( &self, chat_id: C, message_thread_id: ThreadId, ) -> <Bot as Requester>::ReopenForumTopic ⓘ
ReopenForumTopic.Sourcefn delete_forum_topic<C>(
&self,
chat_id: C,
message_thread_id: ThreadId,
) -> <Bot as Requester>::DeleteForumTopic ⓘ
fn delete_forum_topic<C>( &self, chat_id: C, message_thread_id: ThreadId, ) -> <Bot as Requester>::DeleteForumTopic ⓘ
DeleteForumTopic.Sourcefn unpin_all_forum_topic_messages<C>(
&self,
chat_id: C,
message_thread_id: ThreadId,
) -> <Bot as Requester>::UnpinAllForumTopicMessages ⓘ
fn unpin_all_forum_topic_messages<C>( &self, chat_id: C, message_thread_id: ThreadId, ) -> <Bot as Requester>::UnpinAllForumTopicMessages ⓘ
UnpinAllForumTopicMessages.Sourcefn edit_general_forum_topic<C, N>(
&self,
chat_id: C,
name: N,
) -> <Bot as Requester>::EditGeneralForumTopic ⓘ
fn edit_general_forum_topic<C, N>( &self, chat_id: C, name: N, ) -> <Bot as Requester>::EditGeneralForumTopic ⓘ
EditGeneralForumTopic.Sourcefn close_general_forum_topic<C>(
&self,
chat_id: C,
) -> <Bot as Requester>::CloseGeneralForumTopic ⓘ
fn close_general_forum_topic<C>( &self, chat_id: C, ) -> <Bot as Requester>::CloseGeneralForumTopic ⓘ
CloseGeneralForumTopic.Sourcefn reopen_general_forum_topic<C>(
&self,
chat_id: C,
) -> <Bot as Requester>::ReopenGeneralForumTopic ⓘ
fn reopen_general_forum_topic<C>( &self, chat_id: C, ) -> <Bot as Requester>::ReopenGeneralForumTopic ⓘ
ReopenGeneralForumTopic.Sourcefn hide_general_forum_topic<C>(
&self,
chat_id: C,
) -> <Bot as Requester>::HideGeneralForumTopic ⓘ
fn hide_general_forum_topic<C>( &self, chat_id: C, ) -> <Bot as Requester>::HideGeneralForumTopic ⓘ
HideGeneralForumTopic.Sourcefn unhide_general_forum_topic<C>(
&self,
chat_id: C,
) -> <Bot as Requester>::UnhideGeneralForumTopic ⓘ
fn unhide_general_forum_topic<C>( &self, chat_id: C, ) -> <Bot as Requester>::UnhideGeneralForumTopic ⓘ
UnhideGeneralForumTopic.Sourcefn unpin_all_general_forum_topic_messages<C>(
&self,
chat_id: C,
) -> <Bot as Requester>::UnpinAllGeneralForumTopicMessages ⓘ
fn unpin_all_general_forum_topic_messages<C>( &self, chat_id: C, ) -> <Bot as Requester>::UnpinAllGeneralForumTopicMessages ⓘ
UnpinAllGeneralForumTopicMessages.Sourcefn answer_callback_query(
&self,
callback_query_id: CallbackQueryId,
) -> <Bot as Requester>::AnswerCallbackQuery ⓘ
fn answer_callback_query( &self, callback_query_id: CallbackQueryId, ) -> <Bot as Requester>::AnswerCallbackQuery ⓘ
AnswerCallbackQuery.Sourcefn get_user_chat_boosts<C>(
&self,
chat_id: C,
user_id: UserId,
) -> <Bot as Requester>::GetUserChatBoosts ⓘ
fn get_user_chat_boosts<C>( &self, chat_id: C, user_id: UserId, ) -> <Bot as Requester>::GetUserChatBoosts ⓘ
GetUserChatBoosts.Sourcefn set_my_commands<C>(&self, commands: C) -> <Bot as Requester>::SetMyCommands ⓘwhere
C: IntoIterator<Item = BotCommand>,
fn set_my_commands<C>(&self, commands: C) -> <Bot as Requester>::SetMyCommands ⓘwhere
C: IntoIterator<Item = BotCommand>,
SetMyCommands.Sourcefn get_business_connection(
&self,
business_connection_id: BusinessConnectionId,
) -> <Bot as Requester>::GetBusinessConnection ⓘ
fn get_business_connection( &self, business_connection_id: BusinessConnectionId, ) -> <Bot as Requester>::GetBusinessConnection ⓘ
GetBusinessConnection.Sourcefn get_my_commands(&self) -> <Bot as Requester>::GetMyCommands ⓘ
fn get_my_commands(&self) -> <Bot as Requester>::GetMyCommands ⓘ
GetMyCommands.Sourcefn set_my_name(&self) -> <Bot as Requester>::SetMyName ⓘ
fn set_my_name(&self) -> <Bot as Requester>::SetMyName ⓘ
SetMyName.Sourcefn get_my_name(&self) -> <Bot as Requester>::GetMyName ⓘ
fn get_my_name(&self) -> <Bot as Requester>::GetMyName ⓘ
GetMyName.Sourcefn set_my_description(&self) -> <Bot as Requester>::SetMyDescription ⓘ
fn set_my_description(&self) -> <Bot as Requester>::SetMyDescription ⓘ
SetMyDescription.Sourcefn get_my_description(&self) -> <Bot as Requester>::GetMyDescription ⓘ
fn get_my_description(&self) -> <Bot as Requester>::GetMyDescription ⓘ
GetMyDescription.Sourcefn set_my_short_description(&self) -> <Bot as Requester>::SetMyShortDescription ⓘ
fn set_my_short_description(&self) -> <Bot as Requester>::SetMyShortDescription ⓘ
SetMyShortDescription.Sourcefn get_my_short_description(&self) -> <Bot as Requester>::GetMyShortDescription ⓘ
fn get_my_short_description(&self) -> <Bot as Requester>::GetMyShortDescription ⓘ
GetMyShortDescription.SetChatMenuButton.GetChatMenuButton.Sourcefn set_my_default_administrator_rights(
&self,
) -> <Bot as Requester>::SetMyDefaultAdministratorRights ⓘ
fn set_my_default_administrator_rights( &self, ) -> <Bot as Requester>::SetMyDefaultAdministratorRights ⓘ
SetMyDefaultAdministratorRights.Sourcefn get_my_default_administrator_rights(
&self,
) -> <Bot as Requester>::GetMyDefaultAdministratorRights ⓘ
fn get_my_default_administrator_rights( &self, ) -> <Bot as Requester>::GetMyDefaultAdministratorRights ⓘ
GetMyDefaultAdministratorRights.Sourcefn delete_my_commands(&self) -> <Bot as Requester>::DeleteMyCommands ⓘ
fn delete_my_commands(&self) -> <Bot as Requester>::DeleteMyCommands ⓘ
DeleteMyCommands.Sourcefn answer_inline_query<R>(
&self,
inline_query_id: InlineQueryId,
results: R,
) -> <Bot as Requester>::AnswerInlineQuery ⓘwhere
R: IntoIterator<Item = InlineQueryResult>,
fn answer_inline_query<R>(
&self,
inline_query_id: InlineQueryId,
results: R,
) -> <Bot as Requester>::AnswerInlineQuery ⓘwhere
R: IntoIterator<Item = InlineQueryResult>,
AnswerInlineQuery.Sourcefn answer_web_app_query<W>(
&self,
web_app_query_id: W,
result: InlineQueryResult,
) -> <Bot as Requester>::AnswerWebAppQuery ⓘ
fn answer_web_app_query<W>( &self, web_app_query_id: W, result: InlineQueryResult, ) -> <Bot as Requester>::AnswerWebAppQuery ⓘ
AnswerWebAppQuery.Sourcefn save_prepared_inline_message(
&self,
user_id: UserId,
result: InlineQueryResult,
) -> <Bot as Requester>::SavePreparedInlineMessage ⓘ
fn save_prepared_inline_message( &self, user_id: UserId, result: InlineQueryResult, ) -> <Bot as Requester>::SavePreparedInlineMessage ⓘ
SavePreparedInlineMessage.Sourcefn edit_message_text<C, T>(
&self,
chat_id: C,
message_id: MessageId,
text: T,
) -> <Bot as Requester>::EditMessageText ⓘ
fn edit_message_text<C, T>( &self, chat_id: C, message_id: MessageId, text: T, ) -> <Bot as Requester>::EditMessageText ⓘ
EditMessageText.Sourcefn edit_message_text_inline<I, T>(
&self,
inline_message_id: I,
text: T,
) -> <Bot as Requester>::EditMessageTextInline ⓘ
fn edit_message_text_inline<I, T>( &self, inline_message_id: I, text: T, ) -> <Bot as Requester>::EditMessageTextInline ⓘ
EditMessageTextInline.Sourcefn edit_message_caption<C>(
&self,
chat_id: C,
message_id: MessageId,
) -> <Bot as Requester>::EditMessageCaption ⓘ
fn edit_message_caption<C>( &self, chat_id: C, message_id: MessageId, ) -> <Bot as Requester>::EditMessageCaption ⓘ
EditMessageCaption.Sourcefn edit_message_caption_inline<I>(
&self,
inline_message_id: I,
) -> <Bot as Requester>::EditMessageCaptionInline ⓘ
fn edit_message_caption_inline<I>( &self, inline_message_id: I, ) -> <Bot as Requester>::EditMessageCaptionInline ⓘ
EditMessageCaptionInline.Sourcefn edit_message_media<C>(
&self,
chat_id: C,
message_id: MessageId,
media: InputMedia,
) -> <Bot as Requester>::EditMessageMedia ⓘ
fn edit_message_media<C>( &self, chat_id: C, message_id: MessageId, media: InputMedia, ) -> <Bot as Requester>::EditMessageMedia ⓘ
EditMessageMedia.Sourcefn edit_message_media_inline<I>(
&self,
inline_message_id: I,
media: InputMedia,
) -> <Bot as Requester>::EditMessageMediaInline ⓘ
fn edit_message_media_inline<I>( &self, inline_message_id: I, media: InputMedia, ) -> <Bot as Requester>::EditMessageMediaInline ⓘ
EditMessageMediaInline.Sourcefn edit_message_reply_markup<C>(
&self,
chat_id: C,
message_id: MessageId,
) -> <Bot as Requester>::EditMessageReplyMarkup ⓘ
fn edit_message_reply_markup<C>( &self, chat_id: C, message_id: MessageId, ) -> <Bot as Requester>::EditMessageReplyMarkup ⓘ
EditMessageReplyMarkup.Sourcefn edit_message_reply_markup_inline<I>(
&self,
inline_message_id: I,
) -> <Bot as Requester>::EditMessageReplyMarkupInline ⓘ
fn edit_message_reply_markup_inline<I>( &self, inline_message_id: I, ) -> <Bot as Requester>::EditMessageReplyMarkupInline ⓘ
EditMessageReplyMarkupInline.Sourcefn stop_poll<C>(
&self,
chat_id: C,
message_id: MessageId,
) -> <Bot as Requester>::StopPoll ⓘ
fn stop_poll<C>( &self, chat_id: C, message_id: MessageId, ) -> <Bot as Requester>::StopPoll ⓘ
StopPoll.Sourcefn approve_suggested_post<C>(
&self,
chat_id: C,
message_id: MessageId,
) -> <Bot as Requester>::ApproveSuggestedPost ⓘ
fn approve_suggested_post<C>( &self, chat_id: C, message_id: MessageId, ) -> <Bot as Requester>::ApproveSuggestedPost ⓘ
ApproveSuggestedPost.Sourcefn decline_suggested_post<C>(
&self,
chat_id: C,
message_id: MessageId,
) -> <Bot as Requester>::DeclineSuggestedPost ⓘ
fn decline_suggested_post<C>( &self, chat_id: C, message_id: MessageId, ) -> <Bot as Requester>::DeclineSuggestedPost ⓘ
DeclineSuggestedPost.Sourcefn delete_message<C>(
&self,
chat_id: C,
message_id: MessageId,
) -> <Bot as Requester>::DeleteMessage ⓘ
fn delete_message<C>( &self, chat_id: C, message_id: MessageId, ) -> <Bot as Requester>::DeleteMessage ⓘ
DeleteMessage.Sourcefn delete_messages<C, M>(
&self,
chat_id: C,
message_ids: M,
) -> <Bot as Requester>::DeleteMessages ⓘ
fn delete_messages<C, M>( &self, chat_id: C, message_ids: M, ) -> <Bot as Requester>::DeleteMessages ⓘ
DeleteMessages.Sourcefn send_sticker<C>(
&self,
chat_id: C,
sticker: InputFile,
) -> <Bot as Requester>::SendSticker ⓘ
fn send_sticker<C>( &self, chat_id: C, sticker: InputFile, ) -> <Bot as Requester>::SendSticker ⓘ
SendSticker.Sourcefn get_sticker_set<N>(&self, name: N) -> <Bot as Requester>::GetStickerSet ⓘ
fn get_sticker_set<N>(&self, name: N) -> <Bot as Requester>::GetStickerSet ⓘ
GetStickerSet.Sourcefn get_custom_emoji_stickers<C>(
&self,
custom_emoji_ids: C,
) -> <Bot as Requester>::GetCustomEmojiStickers ⓘwhere
C: IntoIterator<Item = CustomEmojiId>,
fn get_custom_emoji_stickers<C>(
&self,
custom_emoji_ids: C,
) -> <Bot as Requester>::GetCustomEmojiStickers ⓘwhere
C: IntoIterator<Item = CustomEmojiId>,
GetCustomEmojiStickers.Sourcefn upload_sticker_file(
&self,
user_id: UserId,
sticker: InputFile,
sticker_format: StickerFormat,
) -> <Bot as Requester>::UploadStickerFile ⓘ
fn upload_sticker_file( &self, user_id: UserId, sticker: InputFile, sticker_format: StickerFormat, ) -> <Bot as Requester>::UploadStickerFile ⓘ
UploadStickerFile.Sourcefn create_new_sticker_set<N, T, S>(
&self,
user_id: UserId,
name: N,
title: T,
stickers: S,
) -> <Bot as Requester>::CreateNewStickerSet ⓘ
fn create_new_sticker_set<N, T, S>( &self, user_id: UserId, name: N, title: T, stickers: S, ) -> <Bot as Requester>::CreateNewStickerSet ⓘ
CreateNewStickerSet.Sourcefn add_sticker_to_set<N>(
&self,
user_id: UserId,
name: N,
sticker: InputSticker,
) -> <Bot as Requester>::AddStickerToSet ⓘ
fn add_sticker_to_set<N>( &self, user_id: UserId, name: N, sticker: InputSticker, ) -> <Bot as Requester>::AddStickerToSet ⓘ
AddStickerToSet.Sourcefn set_sticker_position_in_set<S>(
&self,
sticker: S,
position: u32,
) -> <Bot as Requester>::SetStickerPositionInSet ⓘ
fn set_sticker_position_in_set<S>( &self, sticker: S, position: u32, ) -> <Bot as Requester>::SetStickerPositionInSet ⓘ
SetStickerPositionInSet.Sourcefn delete_sticker_from_set<S>(
&self,
sticker: S,
) -> <Bot as Requester>::DeleteStickerFromSet ⓘ
fn delete_sticker_from_set<S>( &self, sticker: S, ) -> <Bot as Requester>::DeleteStickerFromSet ⓘ
DeleteStickerFromSet.Sourcefn replace_sticker_in_set<N, O>(
&self,
user_id: UserId,
name: N,
old_sticker: O,
sticker: InputSticker,
) -> <Bot as Requester>::ReplaceStickerInSet ⓘ
fn replace_sticker_in_set<N, O>( &self, user_id: UserId, name: N, old_sticker: O, sticker: InputSticker, ) -> <Bot as Requester>::ReplaceStickerInSet ⓘ
ReplaceStickerInSet.Sourcefn set_sticker_set_thumbnail<N>(
&self,
name: N,
user_id: UserId,
format: StickerFormat,
) -> <Bot as Requester>::SetStickerSetThumbnail ⓘ
fn set_sticker_set_thumbnail<N>( &self, name: N, user_id: UserId, format: StickerFormat, ) -> <Bot as Requester>::SetStickerSetThumbnail ⓘ
SetStickerSetThumbnail.Sourcefn set_custom_emoji_sticker_set_thumbnail<N>(
&self,
name: N,
) -> <Bot as Requester>::SetCustomEmojiStickerSetThumbnail ⓘ
fn set_custom_emoji_sticker_set_thumbnail<N>( &self, name: N, ) -> <Bot as Requester>::SetCustomEmojiStickerSetThumbnail ⓘ
SetCustomEmojiStickerSetThumbnail.Sourcefn set_sticker_set_title<N, T>(
&self,
name: N,
title: T,
) -> <Bot as Requester>::SetStickerSetTitle ⓘ
fn set_sticker_set_title<N, T>( &self, name: N, title: T, ) -> <Bot as Requester>::SetStickerSetTitle ⓘ
SetStickerSetTitle.Sourcefn delete_sticker_set<N>(&self, name: N) -> <Bot as Requester>::DeleteStickerSet ⓘ
fn delete_sticker_set<N>(&self, name: N) -> <Bot as Requester>::DeleteStickerSet ⓘ
DeleteStickerSet.Sourcefn set_sticker_emoji_list<S, E>(
&self,
sticker: S,
emoji_list: E,
) -> <Bot as Requester>::SetStickerEmojiList ⓘ
fn set_sticker_emoji_list<S, E>( &self, sticker: S, emoji_list: E, ) -> <Bot as Requester>::SetStickerEmojiList ⓘ
SetStickerEmojiList.Sourcefn set_sticker_keywords<S>(
&self,
sticker: S,
) -> <Bot as Requester>::SetStickerKeywords ⓘ
fn set_sticker_keywords<S>( &self, sticker: S, ) -> <Bot as Requester>::SetStickerKeywords ⓘ
SetStickerKeywords.Sourcefn set_sticker_mask_position<S>(
&self,
sticker: S,
) -> <Bot as Requester>::SetStickerMaskPosition ⓘ
fn set_sticker_mask_position<S>( &self, sticker: S, ) -> <Bot as Requester>::SetStickerMaskPosition ⓘ
SetStickerMaskPosition.Sourcefn get_available_gifts(&self) -> <Bot as Requester>::GetAvailableGifts ⓘ
fn get_available_gifts(&self) -> <Bot as Requester>::GetAvailableGifts ⓘ
GetAvailableGifts.Sourcefn send_gift(
&self,
user_id: UserId,
gift_id: GiftId,
) -> <Bot as Requester>::SendGift ⓘ
fn send_gift( &self, user_id: UserId, gift_id: GiftId, ) -> <Bot as Requester>::SendGift ⓘ
SendGift.Sourcefn send_gift_chat<C>(
&self,
chat_id: C,
gift_id: GiftId,
) -> <Bot as Requester>::SendGiftChat ⓘ
fn send_gift_chat<C>( &self, chat_id: C, gift_id: GiftId, ) -> <Bot as Requester>::SendGiftChat ⓘ
SendGiftChat.GiftPremiumSubscription.Sourcefn verify_user(&self, user_id: UserId) -> <Bot as Requester>::VerifyUser ⓘ
fn verify_user(&self, user_id: UserId) -> <Bot as Requester>::VerifyUser ⓘ
VerifyUser.Sourcefn verify_chat<C>(&self, chat_id: C) -> <Bot as Requester>::VerifyChat ⓘ
fn verify_chat<C>(&self, chat_id: C) -> <Bot as Requester>::VerifyChat ⓘ
VerifyChat.Sourcefn remove_user_verification(
&self,
user_id: UserId,
) -> <Bot as Requester>::RemoveUserVerification ⓘ
fn remove_user_verification( &self, user_id: UserId, ) -> <Bot as Requester>::RemoveUserVerification ⓘ
RemoveUserVerification.Sourcefn remove_chat_verification<C>(
&self,
chat_id: C,
) -> <Bot as Requester>::RemoveChatVerification ⓘ
fn remove_chat_verification<C>( &self, chat_id: C, ) -> <Bot as Requester>::RemoveChatVerification ⓘ
RemoveChatVerification.Sourcefn read_business_message<C>(
&self,
business_connection_id: BusinessConnectionId,
chat_id: C,
message_id: MessageId,
) -> <Bot as Requester>::ReadBusinessMessage ⓘ
fn read_business_message<C>( &self, business_connection_id: BusinessConnectionId, chat_id: C, message_id: MessageId, ) -> <Bot as Requester>::ReadBusinessMessage ⓘ
ReadBusinessMessage.Sourcefn delete_business_messages<M>(
&self,
business_connection_id: BusinessConnectionId,
message_ids: M,
) -> <Bot as Requester>::DeleteBusinessMessages ⓘwhere
M: IntoIterator<Item = MessageId>,
fn delete_business_messages<M>(
&self,
business_connection_id: BusinessConnectionId,
message_ids: M,
) -> <Bot as Requester>::DeleteBusinessMessages ⓘwhere
M: IntoIterator<Item = MessageId>,
DeleteBusinessMessages.Sourcefn set_business_account_name<F>(
&self,
business_connection_id: BusinessConnectionId,
first_name: F,
) -> <Bot as Requester>::SetBusinessAccountName ⓘ
fn set_business_account_name<F>( &self, business_connection_id: BusinessConnectionId, first_name: F, ) -> <Bot as Requester>::SetBusinessAccountName ⓘ
SetBusinessAccountName.Sourcefn set_business_account_username(
&self,
business_connection_id: BusinessConnectionId,
) -> <Bot as Requester>::SetBusinessAccountUsername ⓘ
fn set_business_account_username( &self, business_connection_id: BusinessConnectionId, ) -> <Bot as Requester>::SetBusinessAccountUsername ⓘ
SetBusinessAccountUsername.Sourcefn set_business_account_bio(
&self,
business_connection_id: BusinessConnectionId,
) -> <Bot as Requester>::SetBusinessAccountBio ⓘ
fn set_business_account_bio( &self, business_connection_id: BusinessConnectionId, ) -> <Bot as Requester>::SetBusinessAccountBio ⓘ
SetBusinessAccountBio.Sourcefn set_business_account_profile_photo(
&self,
business_connection_id: BusinessConnectionId,
photo: InputProfilePhoto,
) -> <Bot as Requester>::SetBusinessAccountProfilePhoto ⓘ
fn set_business_account_profile_photo( &self, business_connection_id: BusinessConnectionId, photo: InputProfilePhoto, ) -> <Bot as Requester>::SetBusinessAccountProfilePhoto ⓘ
SetBusinessAccountProfilePhoto.Sourcefn remove_business_account_profile_photo(
&self,
business_connection_id: BusinessConnectionId,
) -> <Bot as Requester>::RemoveBusinessAccountProfilePhoto ⓘ
fn remove_business_account_profile_photo( &self, business_connection_id: BusinessConnectionId, ) -> <Bot as Requester>::RemoveBusinessAccountProfilePhoto ⓘ
RemoveBusinessAccountProfilePhoto.Sourcefn set_business_account_gift_settings(
&self,
business_connection_id: BusinessConnectionId,
show_gift_button: bool,
accepted_gift_types: AcceptedGiftTypes,
) -> <Bot as Requester>::SetBusinessAccountGiftSettings ⓘ
fn set_business_account_gift_settings( &self, business_connection_id: BusinessConnectionId, show_gift_button: bool, accepted_gift_types: AcceptedGiftTypes, ) -> <Bot as Requester>::SetBusinessAccountGiftSettings ⓘ
SetBusinessAccountGiftSettings.Sourcefn get_business_account_star_balance(
&self,
business_connection_id: BusinessConnectionId,
) -> <Bot as Requester>::GetBusinessAccountStarBalance ⓘ
fn get_business_account_star_balance( &self, business_connection_id: BusinessConnectionId, ) -> <Bot as Requester>::GetBusinessAccountStarBalance ⓘ
GetBusinessAccountStarBalance.Sourcefn transfer_business_account_stars(
&self,
business_connection_id: BusinessConnectionId,
star_count: u32,
) -> <Bot as Requester>::TransferBusinessAccountStars ⓘ
fn transfer_business_account_stars( &self, business_connection_id: BusinessConnectionId, star_count: u32, ) -> <Bot as Requester>::TransferBusinessAccountStars ⓘ
TransferBusinessAccountStars.Sourcefn get_business_account_gifts(
&self,
business_connection_id: BusinessConnectionId,
) -> <Bot as Requester>::GetBusinessAccountGifts ⓘ
fn get_business_account_gifts( &self, business_connection_id: BusinessConnectionId, ) -> <Bot as Requester>::GetBusinessAccountGifts ⓘ
GetBusinessAccountGifts.Sourcefn get_user_gifts(&self, user_id: UserId) -> <Bot as Requester>::GetUserGifts ⓘ
fn get_user_gifts(&self, user_id: UserId) -> <Bot as Requester>::GetUserGifts ⓘ
GetUserGifts.Sourcefn get_chat_gifts<C>(&self, chat_id: C) -> <Bot as Requester>::GetChatGifts ⓘ
fn get_chat_gifts<C>(&self, chat_id: C) -> <Bot as Requester>::GetChatGifts ⓘ
GetChatGifts.Sourcefn convert_gift_to_stars(
&self,
business_connection_id: BusinessConnectionId,
owned_gift_id: OwnedGiftId,
) -> <Bot as Requester>::ConvertGiftToStars ⓘ
fn convert_gift_to_stars( &self, business_connection_id: BusinessConnectionId, owned_gift_id: OwnedGiftId, ) -> <Bot as Requester>::ConvertGiftToStars ⓘ
ConvertGiftToStars.Sourcefn upgrade_gift(
&self,
business_connection_id: BusinessConnectionId,
owned_gift_id: OwnedGiftId,
) -> <Bot as Requester>::UpgradeGift ⓘ
fn upgrade_gift( &self, business_connection_id: BusinessConnectionId, owned_gift_id: OwnedGiftId, ) -> <Bot as Requester>::UpgradeGift ⓘ
UpgradeGift.Sourcefn transfer_gift<C>(
&self,
business_connection_id: BusinessConnectionId,
owned_gift_id: OwnedGiftId,
new_owner_chat_id: C,
) -> <Bot as Requester>::TransferGift ⓘ
fn transfer_gift<C>( &self, business_connection_id: BusinessConnectionId, owned_gift_id: OwnedGiftId, new_owner_chat_id: C, ) -> <Bot as Requester>::TransferGift ⓘ
TransferGift.Sourcefn post_story(
&self,
business_connection_id: BusinessConnectionId,
content: InputStoryContent,
active_period: Seconds,
) -> <Bot as Requester>::PostStory ⓘ
fn post_story( &self, business_connection_id: BusinessConnectionId, content: InputStoryContent, active_period: Seconds, ) -> <Bot as Requester>::PostStory ⓘ
PostStory.Sourcefn repost_story<F>(
&self,
business_connection_id: BusinessConnectionId,
from_chat_id: F,
from_story_id: StoryId,
active_period: Seconds,
) -> <Bot as Requester>::RepostStory ⓘ
fn repost_story<F>( &self, business_connection_id: BusinessConnectionId, from_chat_id: F, from_story_id: StoryId, active_period: Seconds, ) -> <Bot as Requester>::RepostStory ⓘ
RepostStory.Sourcefn edit_story(
&self,
business_connection_id: BusinessConnectionId,
story_id: StoryId,
content: InputStoryContent,
) -> <Bot as Requester>::EditStory ⓘ
fn edit_story( &self, business_connection_id: BusinessConnectionId, story_id: StoryId, content: InputStoryContent, ) -> <Bot as Requester>::EditStory ⓘ
EditStory.Sourcefn delete_story(
&self,
business_connection_id: BusinessConnectionId,
story_id: StoryId,
) -> <Bot as Requester>::DeleteStory ⓘ
fn delete_story( &self, business_connection_id: BusinessConnectionId, story_id: StoryId, ) -> <Bot as Requester>::DeleteStory ⓘ
DeleteStory.Sourcefn send_invoice<Ch, T, D, Pa, C, Pri>(
&self,
chat_id: Ch,
title: T,
description: D,
payload: Pa,
currency: C,
prices: Pri,
) -> <Bot as Requester>::SendInvoice ⓘ
fn send_invoice<Ch, T, D, Pa, C, Pri>( &self, chat_id: Ch, title: T, description: D, payload: Pa, currency: C, prices: Pri, ) -> <Bot as Requester>::SendInvoice ⓘ
SendInvoice.Sourcefn create_invoice_link<T, D, Pa, C, Pri>(
&self,
title: T,
description: D,
payload: Pa,
currency: C,
prices: Pri,
) -> <Bot as Requester>::CreateInvoiceLink ⓘwhere
T: Into<String>,
D: Into<String>,
Pa: Into<String>,
C: Into<String>,
Pri: IntoIterator<Item = LabeledPrice>,
fn create_invoice_link<T, D, Pa, C, Pri>(
&self,
title: T,
description: D,
payload: Pa,
currency: C,
prices: Pri,
) -> <Bot as Requester>::CreateInvoiceLink ⓘwhere
T: Into<String>,
D: Into<String>,
Pa: Into<String>,
C: Into<String>,
Pri: IntoIterator<Item = LabeledPrice>,
CreateInvoiceLink.Sourcefn answer_shipping_query(
&self,
shipping_query_id: ShippingQueryId,
ok: bool,
) -> <Bot as Requester>::AnswerShippingQuery ⓘ
fn answer_shipping_query( &self, shipping_query_id: ShippingQueryId, ok: bool, ) -> <Bot as Requester>::AnswerShippingQuery ⓘ
AnswerShippingQuery.Sourcefn answer_pre_checkout_query(
&self,
pre_checkout_query_id: PreCheckoutQueryId,
ok: bool,
) -> <Bot as Requester>::AnswerPreCheckoutQuery ⓘ
fn answer_pre_checkout_query( &self, pre_checkout_query_id: PreCheckoutQueryId, ok: bool, ) -> <Bot as Requester>::AnswerPreCheckoutQuery ⓘ
AnswerPreCheckoutQuery.Sourcefn get_my_star_balance(&self) -> <Bot as Requester>::GetMyStarBalance ⓘ
fn get_my_star_balance(&self) -> <Bot as Requester>::GetMyStarBalance ⓘ
GetMyStarBalance.Sourcefn get_star_transactions(&self) -> <Bot as Requester>::GetStarTransactions ⓘ
fn get_star_transactions(&self) -> <Bot as Requester>::GetStarTransactions ⓘ
GetStarTransactions.Sourcefn refund_star_payment(
&self,
user_id: UserId,
telegram_payment_charge_id: TelegramTransactionId,
) -> <Bot as Requester>::RefundStarPayment ⓘ
fn refund_star_payment( &self, user_id: UserId, telegram_payment_charge_id: TelegramTransactionId, ) -> <Bot as Requester>::RefundStarPayment ⓘ
RefundStarPayment.Sourcefn edit_user_star_subscription(
&self,
user_id: UserId,
telegram_payment_charge_id: TelegramTransactionId,
is_canceled: bool,
) -> <Bot as Requester>::EditUserStarSubscription ⓘ
fn edit_user_star_subscription( &self, user_id: UserId, telegram_payment_charge_id: TelegramTransactionId, is_canceled: bool, ) -> <Bot as Requester>::EditUserStarSubscription ⓘ
EditUserStarSubscription.Sourcefn set_passport_data_errors<E>(
&self,
user_id: UserId,
errors: E,
) -> <Bot as Requester>::SetPassportDataErrors ⓘwhere
E: IntoIterator<Item = PassportElementError>,
fn set_passport_data_errors<E>(
&self,
user_id: UserId,
errors: E,
) -> <Bot as Requester>::SetPassportDataErrors ⓘwhere
E: IntoIterator<Item = PassportElementError>,
SetPassportDataErrors.Sourcefn send_game<C, G>(
&self,
chat_id: C,
game_short_name: G,
) -> <Bot as Requester>::SendGame ⓘ
fn send_game<C, G>( &self, chat_id: C, game_short_name: G, ) -> <Bot as Requester>::SendGame ⓘ
SendGame.Sourcefn set_game_score(
&self,
user_id: UserId,
score: u64,
chat_id: u32,
message_id: MessageId,
) -> <Bot as Requester>::SetGameScore ⓘ
fn set_game_score( &self, user_id: UserId, score: u64, chat_id: u32, message_id: MessageId, ) -> <Bot as Requester>::SetGameScore ⓘ
SetGameScore.Sourcefn set_game_score_inline<I>(
&self,
user_id: UserId,
score: u64,
inline_message_id: I,
) -> <Bot as Requester>::SetGameScoreInline ⓘ
fn set_game_score_inline<I>( &self, user_id: UserId, score: u64, inline_message_id: I, ) -> <Bot as Requester>::SetGameScoreInline ⓘ
SetGameScoreInline.Sourcefn get_game_high_scores<T>(
&self,
user_id: UserId,
target: T,
) -> <Bot as Requester>::GetGameHighScores ⓘwhere
T: Into<TargetMessage>,
fn get_game_high_scores<T>(
&self,
user_id: UserId,
target: T,
) -> <Bot as Requester>::GetGameHighScores ⓘwhere
T: Into<TargetMessage>,
GetGameHighScores.Sourcefn copy_message<C, F>(
&self,
chat_id: C,
from_chat_id: F,
message_id: MessageId,
) -> <Bot as Requester>::CopyMessage ⓘ
fn copy_message<C, F>( &self, chat_id: C, from_chat_id: F, message_id: MessageId, ) -> <Bot as Requester>::CopyMessage ⓘ
CopyMessage.Sourcefn copy_messages<C, F, M>(
&self,
chat_id: C,
from_chat_id: F,
message_ids: M,
) -> <Bot as Requester>::CopyMessages ⓘ
fn copy_messages<C, F, M>( &self, chat_id: C, from_chat_id: F, message_ids: M, ) -> <Bot as Requester>::CopyMessages ⓘ
CopyMessages.Sourcefn unpin_all_chat_messages<C>(
&self,
chat_id: C,
) -> <Bot as Requester>::UnpinAllChatMessages ⓘ
fn unpin_all_chat_messages<C>( &self, chat_id: C, ) -> <Bot as Requester>::UnpinAllChatMessages ⓘ
UnpinAllChatMessages.Auto Trait Implementations
impl Freeze for Bot
impl !RefUnwindSafe for Bot
impl Send for Bot
impl Sync for Bot
impl Unpin for Bot
impl !UnwindSafe for Bot