pub struct Gift {Show 13 fields
pub id: GiftId,
pub sticker: Sticker,
pub star_count: u32,
pub upgrade_star_count: Option<u32>,
pub is_premium: bool,
pub has_colors: bool,
pub total_count: Option<u32>,
pub remaining_count: Option<u32>,
pub personal_total_count: Option<u32>,
pub personal_remaining_count: Option<u32>,
pub background: Option<GiftBackground>,
pub unique_gift_variant_count: Option<u32>,
pub publisher_chat: Option<Chat>,
}Expand description
This object represents a gift that can be sent by the bot.
Fields
id: GiftIdUnique identifier of the gift
sticker: StickerThe sticker that represents the gift
star_count: u32The number of Telegram Stars that must be paid to send the sticker
upgrade_star_count: Option<u32>The number of Telegram Stars that must be paid to upgrade the gift to a unique one
true, if the gift can only be purchased by Telegram Premium
subscribers
has_colors: booltrue, if the gift can be used (after being upgraded) to customize a
user’s appearance
total_count: Option<u32>The total number of the gifts of this type that can be sent; for limited gifts only
remaining_count: Option<u32>The number of remaining gifts of this type that can be sent; for limited gifts only
personal_total_count: Option<u32>The total number of gifts of this type that can be sent by the bot; for limited gifts only
personal_remaining_count: Option<u32>The number of remaining gifts of this type that can be sent by the bot; for limited gifts only
background: Option<GiftBackground>Background of the gift
unique_gift_variant_count: Option<u32>The total number of different unique gifts that can be obtained by upgrading the gift
publisher_chat: Option<Chat>Information about the chat that published the gift
Implementations
Sourceimpl Gift
impl Gift
pub fn is_limited(&self) -> bool
Sourcepub fn limited_count(&self) -> Option<(u32, u32)>
pub fn limited_count(&self) -> Option<(u32, u32)>
Returns None if Gift isn’t limited or a tuple where first element is
Self::remaining_count and second is Self::total_count