pub struct InlineQueryResultContact {
pub id: String,
pub phone_number: String,
pub first_name: String,
pub last_name: Option<String>,
pub vcard: Option<String>,
pub reply_markup: Option<InlineKeyboardMarkup>,
pub input_message_content: Option<InputMessageContent>,
pub thumbnail_url: Option<Url>,
pub thumbnail_width: Option<u32>,
pub thumbnail_height: Option<u32>,
}Expand description
Represents a contact with a phone number.
By default, this contact will be sent by the user. Alternatively, you can
use input_message_content to send a message with the specified content
instead of the contact.
Fields
id: StringUnique identifier for this result, 1-64 Bytes.
phone_number: StringContact’s phone number.
first_name: StringContact’s first name.
last_name: Option<String>Contact’s last name.
vcard: Option<String>Additional data about the contact in the form of a vCard, 0-2048 bytes.
reply_markup: Option<InlineKeyboardMarkup>Inline keyboard attached to the message.
input_message_content: Option<InputMessageContent>Content of the message to be sent instead of the contact.
thumbnail_url: Option<Url>Url of the thumbnail for the result.
thumbnail_width: Option<u32>Thumbnail width.
thumbnail_height: Option<u32>Thumbnail height.
Implementations
Sourceimpl InlineQueryResultContact
impl InlineQueryResultContact
pub fn new<S1, S2, S3>( id: S1, phone_number: S2, first_name: S3, ) -> InlineQueryResultContact
pub fn id<S>(self, val: S) -> InlineQueryResultContact
pub fn phone_number<S>(self, val: S) -> InlineQueryResultContact
pub fn first_name<S>(self, val: S) -> InlineQueryResultContact
pub fn last_name<S>(self, val: S) -> InlineQueryResultContact
pub fn vcard<S>(self, val: S) -> InlineQueryResultContact
pub fn reply_markup(self, val: InlineKeyboardMarkup) -> InlineQueryResultContact
pub fn input_message_content( self, val: InputMessageContent, ) -> InlineQueryResultContact
pub fn thumbnail_url(self, val: Url) -> InlineQueryResultContact
pub fn thumbnail_width(self, val: u32) -> InlineQueryResultContact
pub fn thumbnail_height(self, val: u32) -> InlineQueryResultContact