pub struct InlineQueryResultLocation {Show 13 fields
pub id: String,
pub latitude: f64,
pub longitude: f64,
pub title: String,
pub horizontal_accuracy: Option<f64>,
pub live_period: Option<LivePeriod>,
pub heading: Option<u16>,
pub proximity_alert_radius: Option<u32>,
pub reply_markup: Option<InlineKeyboardMarkup>,
pub input_message_content: Option<InputMessageContent>,
pub thumbnail_url: Option<Url>,
pub thumbnail_width: Option<u32>,
pub thumbnail_height: Option<u32>,
}Expand description
Represents a location on a map.
By default, the location will be sent by the user. Alternatively, you can
use input_message_content to send a message with the specified content
instead of the location.
Fields
id: StringUnique identifier for this result, 1-64 Bytes.
latitude: f64Location latitude in degrees.
longitude: f64Location longitude in degrees.
title: StringLocation title.
horizontal_accuracy: Option<f64>The radius of uncertainty for the location, measured in meters; 0-1500
live_period: Option<LivePeriod>Period in seconds for which the location can be updated, should be between 60 and 86400, or 0x7FFFFFFF for live locations that can be edited indefinitely.
heading: Option<u16>For live locations, a direction in which the user is moving, in degrees. Must be between 1 and 360 if specified.
proximity_alert_radius: Option<u32>For live locations, a maximum distance for proximity alerts about approaching another chat member, in meters. Must be between 1 and 100000 if specified.
reply_markup: Option<InlineKeyboardMarkup>Inline keyboard attached to the message.
input_message_content: Option<InputMessageContent>Content of the message to be sent instead of the location.
thumbnail_url: Option<Url>Url of the thumbnail for the result.
thumbnail_width: Option<u32>Thumbnail width.
thumbnail_height: Option<u32>Thumbnail height.
Implementations
Sourceimpl InlineQueryResultLocation
impl InlineQueryResultLocation
pub fn new<S1, S2>( id: S1, title: S2, latitude: f64, longitude: f64, ) -> InlineQueryResultLocation
pub fn id<S>(self, val: S) -> InlineQueryResultLocation
pub fn latitude(self, val: f64) -> InlineQueryResultLocation
pub fn longitude(self, val: f64) -> InlineQueryResultLocation
pub fn title<S>(self, val: S) -> InlineQueryResultLocation
pub fn horizontal_accuracy<S>(self, val: f64) -> InlineQueryResultLocation
pub fn live_period(self, val: LivePeriod) -> InlineQueryResultLocation
pub fn heading(self, val: u16) -> InlineQueryResultLocation
pub fn proximity_alert_radius(self, val: u32) -> InlineQueryResultLocation
pub fn reply_markup( self, val: InlineKeyboardMarkup, ) -> InlineQueryResultLocation
pub fn input_message_content( self, val: InputMessageContent, ) -> InlineQueryResultLocation
pub fn thumbnail_url(self, val: Url) -> InlineQueryResultLocation
pub fn thumbnail_width(self, val: u32) -> InlineQueryResultLocation
pub fn thumbnail_height(self, val: u32) -> InlineQueryResultLocation