pub struct InlineQueryResultVenue {Show 14 fields
pub id: String,
pub latitude: f64,
pub longitude: f64,
pub title: String,
pub address: String,
pub foursquare_id: Option<String>,
pub foursquare_type: Option<String>,
pub google_place_id: Option<String>,
pub google_place_type: Option<String>,
pub reply_markup: Option<InlineKeyboardMarkup>,
pub input_message_content: Option<InputMessageContent>,
pub thumbnail_url: Option<Url>,
pub thumbnail_width: Option<u32>,
pub thumbnail_height: Option<u32>,
}Expand description
Represents a venue.
By default, the venue will be sent by the user. Alternatively, you can use
input_message_content to send a message with the specified content instead
of the venue.
Fields
id: StringUnique identifier for this result, 1-64 Bytes.
latitude: f64Latitude of the venue location in degrees.
longitude: f64Longitude of the venue location in degrees.
title: StringTitle of the venue.
address: StringAddress of the venue.
foursquare_id: Option<String>Foursquare identifier of the venue if known.
foursquare_type: Option<String>Foursquare type of the venue, if known. (For example,
arts_entertainment/default, arts_entertainment/aquarium or
food/icecream.)
google_place_id: Option<String>Google Places identifier of the venue.
google_place_type: Option<String>Google Places type of the venue. (See supported types.)
reply_markup: Option<InlineKeyboardMarkup>Inline keyboard attached to the message.
input_message_content: Option<InputMessageContent>Content of the message to be sent instead of the venue.
thumbnail_url: Option<Url>Url of the thumbnail for the result.
thumbnail_width: Option<u32>Thumbnail width.
thumbnail_height: Option<u32>Thumbnail height.
Implementations
Sourceimpl InlineQueryResultVenue
impl InlineQueryResultVenue
pub fn new<S1, S2, S3>( id: S1, latitude: f64, longitude: f64, title: S2, address: S3, ) -> InlineQueryResultVenue
pub fn id<S>(self, val: S) -> InlineQueryResultVenue
pub fn latitude(self, val: f64) -> InlineQueryResultVenue
pub fn longitude(self, val: f64) -> InlineQueryResultVenue
pub fn title<S>(self, val: S) -> InlineQueryResultVenue
pub fn address<S>(self, val: S) -> InlineQueryResultVenue
pub fn foursquare_id<S>(self, val: S) -> InlineQueryResultVenue
pub fn foursquare_type<S>(self, val: S) -> InlineQueryResultVenue
pub fn google_place_id<S>(self, val: S) -> InlineQueryResultVenue
pub fn google_place_type<S>(self, val: S) -> InlineQueryResultVenue
pub fn reply_markup(self, val: InlineKeyboardMarkup) -> InlineQueryResultVenue
pub fn input_message_content( self, val: InputMessageContent, ) -> InlineQueryResultVenue
pub fn thumbnail_url(self, val: Url) -> InlineQueryResultVenue
pub fn thumbnail_width(self, val: u32) -> InlineQueryResultVenue
pub fn thumbnail_height(self, val: u32) -> InlineQueryResultVenue