pub struct MessageCommon {Show 16 fields
pub author_signature: Option<String>,
pub paid_star_count: Option<u32>,
pub effect_id: Option<EffectId>,
pub forward_origin: Option<MessageOrigin>,
pub reply_to_message: Option<Box<Message>>,
pub external_reply: Option<ExternalReplyInfo>,
pub quote: Option<TextQuote>,
pub reply_to_story: Option<Story>,
pub sender_boost_count: Option<u16>,
pub edit_date: Option<DateTime<Utc>>,
pub media_kind: MediaKind,
pub reply_markup: Option<InlineKeyboardMarkup>,
pub is_automatic_forward: bool,
pub has_protected_content: bool,
pub is_from_offline: bool,
pub business_connection_id: Option<BusinessConnectionId>,
}Fields
Signature of the post author for messages in channels, or the custom title of an anonymous group administrator.
paid_star_count: Option<u32>The number of Telegram Stars that were paid by the sender of the message to send it
effect_id: Option<EffectId>Unique identifier of the message effect added to the message
forward_origin: Option<MessageOrigin>Information about the original message for forwarded messages
reply_to_message: Option<Box<Message>>For replies, the original message. Note that the Message object in this
field will not contain further reply_to_message fields even if it
itself is a reply.
external_reply: Option<ExternalReplyInfo>Information about the message that is being replied to, which may come from another chat or forum topic
quote: Option<TextQuote>For replies that quote part of the original message, the quoted part of the message
reply_to_story: Option<Story>For replies to a story, the original story
sender_boost_count: Option<u16>If the sender of the message boosted the chat, the number of boosts added by the user
edit_date: Option<DateTime<Utc>>Date the message was last edited in Unix time.
media_kind: MediaKindreply_markup: Option<InlineKeyboardMarkup>Inline keyboard attached to the message. login_url buttons are
represented as ordinary url buttons.
is_automatic_forward: booltrue, if the message is a channel post that was automatically
forwarded to the connected discussion group.
has_protected_content: booltrue, if the message can’t be forwarded.
is_from_offline: booltrue, if the message was sent by an implicit action, for example, as
an away or a greeting business message, or as a scheduled message
business_connection_id: Option<BusinessConnectionId>Unique identifier of the business connection from which the message was received. If non-empty, the message belongs to a chat of the corresponding business account that is independent from any potential bot chat which might share the same identifier.