Sticker

Struct Sticker 

pub struct Sticker {
    pub file: FileMeta,
    pub width: u16,
    pub height: u16,
    pub kind: StickerKind,
    pub flags: StickerFormatFlags,
    pub thumbnail: Option<PhotoSize>,
    pub emoji: Option<String>,
    pub set_name: Option<String>,
    pub needs_repainting: bool,
}
This object represents a sticker.

The official docs.

Fields

file: FileMeta

Metadata of the sticker file.

width: u16

Sticker width, in pixels.

You can assume that max(width, height) = 512, min(width, height) <= 512. In other words one dimension is exactly 512 pixels and the other is at most 512 pixels.

height: u16

Sticker height, in pixels.

You can assume that max(width, height) = 512, min(width, height) <= 512. In other words one dimension is exactly 512 pixels and the other is at most 512 pixels.

kind: StickerKind

Kind of this sticker - regular, mask or custom emoji.

In other words this represent how the sticker is presented, as a big picture/video, as a mask while editing pictures or as a custom emoji in messages.

flags: StickerFormatFlags

Format flags of this sticker:

(is_animated, is_video) == (false, false) - raster/.webp or is_animated == true - animated/.tgs or is_video == true - video/.webm.

In other words this represents how the sticker is encoded.

thumbnail: Option<PhotoSize>

Sticker thumbnail in the .webp or .jpg format.

emoji: Option<String>

Emoji associated with the sticker.

set_name: Option<String>

Name of the sticker set to which the sticker belongs.

needs_repainting: bool

True, if the sticker must be repainted to a text color in messages, the color of the Telegram Premium badge in emoji status, white color on chat photos, or another appropriate color in other places

Implementations

Source

impl Sticker

pub fn format(&self) -> StickerFormat

Returns the format of the Sticker based on the self.flags values

pub fn is_static(&self) -> bool

Returns true is this is a “normal” raster sticker.

Alias to self.format().is_static().

pub fn is_animated(&self) -> bool

Returns true is this is an animated sticker.

Alias to self.format().is_animated().

pub fn is_video(&self) -> bool

Returns true is this is a video sticker.

Alias to self.format().is_video().

Methods from Deref<Target = StickerKind>

pub fn type_(&self) -> StickerType

pub fn is_regular(&self) -> bool

Returns true if the sticker kind is Regular.

pub fn is_mask(&self) -> bool

Returns true if the sticker kind is Mask.

pub fn is_custom_emoji(&self) -> bool

Returns true if the sticker kind is CustomEmoji.

pub fn premium_animation(&self) -> Option<&FileMeta>

pub fn mask_position(&self) -> Option<MaskPosition>

pub fn custom_emoji_id(&self) -> Option<&CustomEmojiId>