pub struct TextQuote {
pub text: String,
pub entities: Vec<MessageEntity>,
pub position: u32,
pub is_manual: bool,
}Expand description
This object contains information about the quoted part of a message that is replied to by the given message.
Fields
text: StringText of the quoted part of a message that is replied to by the given message
entities: Vec<MessageEntity>Special entities that appear in the quote. Currently, only bold, italic, underline, strikethrough, spoiler, and custom_emoji entities are kept in quotes.
position: u32Approximate quote position in the original message in UTF-16 code units as specified by the sender
is_manual: boolTrue, if the quote was chosen manually by the message sender. Otherwise, the quote was added automatically by the server.